SystemOrganization addCategory: #'MEG-Tests'!
SystemOrganization addCategory: 'MEG-Tests-Factories'!
SystemOrganization addCategory: 'MEG-Tests-Factories-Tests'!
SystemOrganization addCategory: 'MEG-Tests-Integration-Collaboration'!
SystemOrganization addCategory: 'MEG-Tests-Integration-Movie'!
SystemOrganization addCategory: 'MEG-Tests-Roadmap'!
SystemOrganization addCategory: 'MEG-Tests-Unit'!

TestCase subclass: #EruCreatesTheWorld
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Movie'!

!EruCreatesTheWorld methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:48'!
test_01_WorldCreation

	| world gandalf rivendell elrond  |
	world := MEGWorld new.
	rivendell := MEGSiteFactory new newSiteNamed: 'Rivendell'.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	elrond := MEGCharacter named: 'Elrond' homeSiteNamed: 'Rivendell'.
	
	world addSite: rivendell.
	world addCharacter: gandalf.
	world addCharacter: elrond.
	
! !

!EruCreatesTheWorld methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:53'!
test_02_SitesForCharactersShouldAlreadyBeInTheWorld

	| world gandalf rivendell elrond |
	world := MEGWorld new.
	rivendell := MEGSiteFactory new newSiteNamed: 'Rivendell'.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	elrond := MEGCharacter named: 'Elrond' homeSiteNamed: 'Rivendell'.
	
	self should: [world addCharacter: elrond] raise: NotFound.
	self should: [world addCharacter: gandalf] raise: NotFound.
	world addSite: rivendell.
	world addCharacter: elrond.
	world addCharacter: gandalf.
	
! !

TestCase subclass: #FromBagEndToMinasTirith
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Movie'!

!FromBagEndToMinasTirith methodsFor: 'public' stamp: 'FedericoFigueredo 6/16/2016 08:32'!
test_01_InitialPartyFormsAtBagEnd
	| world jugador1 company |
	world := MEGWorldFactory new newWorld.
	jugador1 := world agentNamed: 'Jugador 1'.
	
	self assert: jugador1 currentInfluence = 20.

	jugador1 
		recruit: 'Frodo' at: 'Bag End' inCompany: 'Hobbits';
		recruit: 'Sam Gamgee' at: 'Bag End' inTheSameCompanyAs: 'Frodo';
		recruit: 'Pippin' at: 'Bag End' inTheSameCompanyAs: 'Sam Gamgee';
		recruit: 'Merry' at: 'Bag End' inCompany: 'Hobbits'.
	
	company := jugador1 companyNamed: 'Hobbits'.
	self assert: jugador1 currentInfluence = 3.
	self assert: company size = 4.
	self assert: company site = (world siteNamed: 'Bag End').
	^ world.
	
	! !

!FromBagEndToMinasTirith methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 19:49'!
test_02_TheHobbitsTravelToRivendell
	| world jugador1 company |
	world := self test_01_InitialPartyFormsAtBagEnd.
	jugador1 := world agentNamed: 'Jugador 1'.
	company := jugador1 companyNamed: 'Hobbits'.
	
	jugador1 move: 'Hobbits' to: 'Rivendell'.
	self assert: company site = (world siteNamed: 'Rivendell').
	^ world.! !

!FromBagEndToMinasTirith methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 19:47'!
test_03_TheCompanyAssemblesInRivendell
	"Agregamos a Gandalf y Aragorn al grupo de Hobbits"
	| world jugador1 company |
	world := self test_02_TheHobbitsTravelToRivendell.
	jugador1 := world agentNamed: 'Jugador 1'.
	company := jugador1 companyNamed: 'Hobbits'.

	jugador1 
		recruit: 'Gandalf' at: 'Rivendell' inCompany: 'Hobbits';
		recruit: 'Aragorn II' at: 'Rivendell' under: 'Gandalf'.
	
	company := jugador1 companyNamed: 'Hobbits'.
	self assert: jugador1 currentInfluence = 3.
	self assert: (world characterNamed: 'Gandalf') currentInfluence = 1.
	self assert: company size = 6.
	self assert: company site = (world siteNamed: 'Rivendell').
	self assert: (world siteNamed: 'Rivendell') occupants size = 6.
	^ world.
	
	! !

!FromBagEndToMinasTirith methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 11:42'!
test_04_Failure_TheCompanyTravelsToMinasTirithAndRecruitsAFaction
	| world jugador1 company result aragornII menOfAnorien |
	world := self test_03_TheCompanyAssemblesInRivendell.
	jugador1 := world agentNamed: 'Jugador 1'.
	jugador1 randomNumberGenerator: [ 6 ].
	company := jugador1 companyNamed: 'Hobbits'.
	aragornII := world characterNamed: 'Aragorn II'.
	menOfAnorien := world factionNamed: 'Men of Anorien'.

	jugador1 move: 'Hobbits' to: 'Lorien'.
	jugador1 move: 'Hobbits' to: 'Minas Tirith'.
	
	self assert: jugador1 currentMarshallingPoints = 8. "La suma de los MP de los personajes en la compañía Hobbits"
	self assert: menOfAnorien agentFollowed isNil.
	self deny: (jugador1 factions includes: menOfAnorien).
	self assert: aragornII isAvailable.
	self assert: company isAvailable.
	
	result := jugador1 recruitFaction: 'Men of Anorien' with: 'Aragorn II'.
	
	self assert: (result object at: 'recruitmentCheck') <= 7.
	self assert: jugador1 currentMarshallingPoints = 8.
	self assert: menOfAnorien agentFollowed isNil.
	self deny: (jugador1 factions includes: menOfAnorien).
	self assert: aragornII isUnavailable.
	self assert: company isAvailable.! !

!FromBagEndToMinasTirith methodsFor: 'public' stamp: 'FedericoFigueredo 6/24/2016 08:35'!
test_04_Success_TheCompanyTravelsToMinasTirithAndRecruitsAFaction
	| world jugador1 company result aragornII menOfAnorien |
	world := self test_03_TheCompanyAssemblesInRivendell.
	jugador1 := world agentNamed: 'Jugador 1'.
	jugador1 randomNumberGenerator: [ 8 ].
	company := jugador1 companyNamed: 'Hobbits'.
	aragornII := world characterNamed: 'Aragorn II'.
	menOfAnorien := world factionNamed: 'Men of Anorien'.

	jugador1 move: 'Hobbits' to: 'Lorien'.
	jugador1 move: 'Hobbits' to: 'Minas Tirith'.
	
	self assert: jugador1 currentMarshallingPoints = 8. "La suma de los MP de los personajes en la compañía Hobbits"
	self assert: menOfAnorien agentFollowed isNil.
	self deny: (jugador1 factions includes: menOfAnorien).
	self assert: aragornII isAvailable.
	self assert: company isAvailable.
	
	result := jugador1 recruitFaction: 'Men of Anorien' with: 'Aragorn II'.
	
	self assert: (result object at: 'recruitmentCheck') > 7.
	self assert: jugador1 currentMarshallingPoints = 10.
	self assert: menOfAnorien agentFollowed = jugador1.
	self assert: (jugador1 factions includes: menOfAnorien).
	self assert: aragornII isUnavailable.
	self assert: company isUnavailable.
	
	^ world.! !

!FromBagEndToMinasTirith methodsFor: 'public' stamp: 'FedericoFigueredo 6/24/2016 08:52'!
test_05_TheCompanyLeavesMinasTirithVictoriously
	| world jugador1 company aragornII |
	world := self test_04_Success_TheCompanyTravelsToMinasTirithAndRecruitsAFaction.
	jugador1 := world agentNamed: 'Jugador 1'.
	company := jugador1 companyNamed: 'Hobbits'.
	aragornII := world characterNamed: 'Aragorn II'.
	
	self assert: company isUnavailable.
	self assert: aragornII isUnavailable.
	
	jugador1 makeAllXYZsButCompaniesAvailable.
	
	self assert: company isUnavailable.
	self assert: aragornII isAvailable.
	
	jugador1 move: company to: 'Lorien'.
	
	self assert: company isAvailable.
	self assert: aragornII isAvailable.
	
	^ world.
	
	! !

TestCase subclass: #HomeSiteCriteriaTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!HomeSiteCriteriaTest commentStamp: '<historical>' prior: 0!
A HomeSiteCriteriaTest is a test class for testing the behavior of HomeSiteCriteria!

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 6/11/2016 19:25'!
test_01_CreationOfNamedCriteria

	| criteria |
	criteria := HomeSiteCriteria named: 'Rivendell'.
	self assert: criteria name = 'Rivendell'.
! !

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 6/11/2016 19:25'!
test_02_CreationOfTypeCriteria

	| criteria |
	criteria := HomeSiteCriteria type: 'Haven'.
	self assert: criteria type = 'Haven'.
! !

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 19:37'!
test_03_CreationOfNamedNamedCriteria

	| criteria |
	criteria := HomeSiteCriteria named: 'Rivendell' named: 'Bree'.
	self assert: criteria name = 'Rivendell'.
	self assert: criteria name2 = 'Bree'.
! !

TestCase subclass: #MEGAgentCollaborationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Collaboration'!

!MEGAgentCollaborationTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 16:22'!
test_01_MakeAllXYZsButCompaniesAvailable 

	| world character company agent |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Aragorn II' at: 'Bree' for: 'Jugador 1'.
	agent := world agentNamed: 'Jugador 1'.
	character := world characterNamed: 'Aragorn II'.
	company := character company.
	
	character reasonForBeingUnavailable: 'Testing'.
	company reasonForBeingUnavailable: 'Testing'.
	self assert: character isUnavailable.
	self assert: company isUnavailable.
	agent makeAllXYZsButCompaniesAvailable.
	self assert: character isAvailable.
	self assert: company isUnavailable.
	! !

!MEGAgentCollaborationTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 16:44'!
test_02_MoveTo

	| world character company agent origin destination |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Aragorn II' at: 'Bree' for: 'Jugador 1' inCompany: 'Lone Ranger'.
	agent := world agentNamed: 'Jugador 1'.
	character := world characterNamed: 'Aragorn II'.
	company := character company.
	origin := world siteNamed: 'Bree'.
	destination := world siteNamed: 'Rivendell'.

	company reasonForBeingUnavailable: 'Testing'.
	self assert: (origin includesOccupant: character).
	self deny: (destination includesOccupant: character).
	self assert: character currentSite name = 'Bree'.
	self assert: company isUnavailable.
	agent move: 'Lone Ranger' to: 'Rivendell'.
	self deny: (origin includesOccupant: character).
	self assert: (destination includesOccupant: character).
	self assert: character currentSite name = 'Rivendell'.
	self assert: company isAvailable.
	! !

TestCase subclass: #MEGAgentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGAgentTest commentStamp: '<historical>' prior: 0!
A MEGAgentTest is a test class for testing the behavior of MEGAgent!

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:48'!
test_01_Defaults

	| agent |
	agent := MEGAgent new.
	self assert: agent agentFollowed = agent.
	self assert: agent baseInfluence = 20.
	self assert: agent companies isEmpty.
	self assert: agent currentGeneralInfluence = 20.
	self assert: agent currentInfluence = 20.
	self assert: agent currentMarshallingPoints = 0.
	self assert: agent factions isEmpty.
	self assert: agent followers isEmpty.
	self assert: agent name isNil.
	self assert: agent randomNumberGenerator isNil.
	self assert: agent sumOfInfluencedMinds = 0.
	self assert: agent influenced isEmpty.
	self assert: agent world isNil.! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:37'!
test_02_Creation
	| agent |
	agent := MEGAgent named: 'Player 1'.
	self assert: agent name = 'Player 1'.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 17:52'!
test_03_AddFaction

	| agent faction |
	agent := MEGAgent named: 'Player 1'.
	faction := MEGResource new.
	self assert: faction agentFollowed isNil.
	self assert: agent factions isEmpty.
	agent addFaction: faction.
	self assert: faction agentFollowed = agent.
	self assert: agent factions first = faction.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:48'!
test_04_AddInfluenced

	| agent directFollower |
	agent := MEGAgent named: 'Player 1'.
	directFollower := MEGCharacter new.
	agent addInfluenced: directFollower.
	self assert: agent influenced first = directFollower.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:45'!
test_05_Companies

	| agent follower company  |
	agent := MEGAgent named: 'Player 1'.
	company := MEGCompany new.
	follower := MEGCharacter new.
	follower company: company.
	agent influence: follower.
	self assert: (agent companies includes: company).
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:45'!
test_06_CompanyNamed

	| agent follower company  |
	agent := MEGAgent named: 'Player 1'.
	company := MEGCompany named: 'Unnamed char'.
	follower := MEGCharacter new.
	follower company: company.
	agent influence: follower.
	self assert: (agent companyNamed: 'Unnamed char') = company.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:45'!
test_07_CompanyNamedIfNone

	| agent follower company testResult |
	agent := MEGAgent named: 'Player 1'.
	company := MEGCompany named: 'Unnamed char'.
	follower := MEGCharacter new.
	follower company: company.
	agent influence: follower.
	testResult := agent companyNamed: 'Misspelled company name' ifNone: [true].
	self assert: testResult.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:47'!
test_08_CurrentGeneralInfluence

	| agent follower |
	agent := MEGAgent named: 'Player 1'.
	follower := MEGCharacter new.
	follower mind: 5.
	agent addInfluenced: follower.
	self assert: agent currentGeneralInfluence = 15.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:47'!
test_09_CurrentInfluence

	| agent directFollower |
	agent := MEGAgent named: 'Player 1'.
	directFollower := MEGCharacter new.
	directFollower mind: 4.
	agent addInfluenced: directFollower.
	self assert: agent currentInfluence = 16.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 16:45'!
test_10_CurrentMarshallingPoints

	| agent directFollower faction |
	agent := MEGAgent named: 'Player 1'.
	directFollower := MEGCharacter new.
	directFollower marshallingPoints: 2.
	faction := MEGResource new.
	faction marshallingPoints: 3.
	self assert: agent currentMarshallingPoints = 0.
	agent influence: directFollower.
	self assert: agent currentMarshallingPoints = 2.
	agent addFaction: faction.
	self assert: agent currentMarshallingPoints = 5.
! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 18:25'!
test_11_NewCompanyMoveAction

	| agent world |
	world := MEGWorld new.
	agent := MEGAgent named: 'Player 1'.
	agent world: world.
	self assert: agent newCompanyMoveAction world = world.! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 18:26'!
test_12_NewRecruitAction

	| agent world |
	world := MEGWorld new.
	agent := MEGAgent named: 'Player 1'.
	agent world: world.
	self assert: agent newRecruitAction world = world.! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 18:27'!
test_13_NewRecruitFactionAction

	| agent world |
	world := MEGWorld new.
	agent := MEGAgent named: 'Player 1'.
	agent world: world.
	agent randomNumberGenerator: 8.
	self assert: agent newRecruitFactionAction world = world.
	self assert: agent newRecruitFactionAction randomNumberGenerator = 8.
	! !

TestCase subclass: #MEGCharacterFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGCharacterFactoryTest commentStamp: '<historical>' prior: 0!
A MEGCharacterFactoryTest is a test class for testing the behavior of MEGCharacterFactory!

!MEGCharacterFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:20'!
test_01_NewCharacters

	| chars |
	chars := MEGCharacterFactory new newCharacters.
	self assert: chars notEmpty.! !

!MEGCharacterFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:58'!
test_02_NewCharacterNamed

	| character |
	character := MEGCharacterFactory new newCharacterNamed: 'Wacho'.
	self assert: character notNil.
	! !

TestCase subclass: #MEGCharacterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGCharacterTest commentStamp: '<historical>' prior: 0!
A MEGCharacterTest is a test class for testing the behavior of MEGCharacter!

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 13:49'!
test_01_Defaults

	| character |
	character := MEGCharacter new.
	self assert: character currentInfluence isZero.
	self assert: character currentDirectInfluence isZero.
	self assert: character company isNil.
	self assert: character homeSiteCriteria isNil.
	self assert: character isAvailable.
	self assert: character isUnavailable not.
	self assert: character marshallingPoints isZero.
	self assert: character name isNil.
	self assert: character reasonForBeingUnavailable isNil.	
! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:35'!
test_02_CreationWithHomeSiteNamed
	| character |
	character := MEGCharacter named: 'Bilbo' homeSiteNamed: 'Bag Ends'.
	self assert: character name = 'Bilbo'.
	self assert: character homeSiteCriteria notNil.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:45'!
test_03_CreationWithHomeSiteType
	| character |
	character := MEGCharacter named: 'Bilbo' homeSiteType: 'Haven'.
	self assert: character name = 'Bilbo'.
	self assert: character homeSiteCriteria notNil.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:10'!
test_04_SettingFollowedCharacter

	| character pipo |
	pipo := (MEGCharacter named: 'Pipo Pescador' homeSiteNamed: 'Lago Traful').
	character := MEGCharacter new.
	character characterFollowed: pipo.
	self assert: character characterFollowed = pipo.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:12'!
test_05_SettingCurrentSite

	| character site |
	site := MEGSite named: 'Lago Traful'.
	character := MEGCharacter new.
	character currentSite: site.
	self assert: character currentSite = site.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/14/2016 18:30'!
test_06_AgentFollowedDirectly

	| peronismo peron |
	peronismo := MEGAgent named: 'Peronismo'.
	peron := MEGCharacter new name: 'Peron'.
	self assert: peron agentFollowed isNil.
	peron characterFollowed: peronismo.
	self assert: peron agentFollowed = peronismo.
	peron directInfluencer: peronismo.
	self assert: peron agentFollowed = peronismo.
	! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/14/2016 18:29'!
test_07_AgentFollowedIndirectly

	| peronismo peron cafiero |
	peronismo := MEGAgent named: 'Peronismo'.
	peron := MEGCharacter new name: 'Peron'.
	peron directInfluencer: peronismo.
	self assert: peron agentFollowed = peronismo.
	cafiero := MEGCharacter new name: 'Cafiero'.
	cafiero directInfluencer: peron.
	self assert: cafiero agentFollowed = peronismo.
	self assert: cafiero characterFollowed = peron.
	! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 13:57'!
test_08_ReasonForBeingUnavailableNotNil

	| character |
	character := MEGCharacter new.
	character reasonForBeingUnavailable: 'Testing'.
	self assert: character isAvailable not.
	self assert: character isUnavailable.
	self assert: character reasonForBeingUnavailable = 'Testing'.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 14:22'!
test_09_BecomeAvailable

	| character |
	character := MEGCharacter new.
	character reasonForBeingUnavailable: 'Testing'.
	self assert: character isAvailable not.
	self assert: character isUnavailable.
	character becomeAvailable.
	self assert: character isAvailable.
	self assert: character isUnavailable not.
	self assert: character reasonForBeingUnavailable isNil.
! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 14:32'!
test_10_CompanyMethods

	| character company |
	character := MEGCharacter new.
	company := MEGCompany named: 'Solo Boy'.
	self assert: character company isNil.
	self assert: character companyForCharacterUnderYourInfluence isNil.
	character company: company.
	self assert: character company = company.
	self assert: character companyForCharacterUnderYourInfluence = company.
! !

TestCase subclass: #MEGCompanyMoveActionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGCompanyMoveActionTest commentStamp: '<historical>' prior: 0!
A MEGCompanyMoveActionTest is a test class for testing the behavior of MEGCompanyMoveAction!

!MEGCompanyMoveActionTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 17:05'!
test_01_Defaults

	| action |
	action := MEGCompanyMoveAction new.
	self assert: action world isNil.
	self assert: action agent isNil.
	self assert: action company isNil.
	self assert: action destination isNil.
! !

!MEGCompanyMoveActionTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 17:07'!
test_02_ConstructorMethod

	| world action |
	world := MEGWorld new.
	action := MEGCompanyMoveAction world: world.
	self assert: action world = world.
	! !

!MEGCompanyMoveActionTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 17:10'!
test_03_SetAgent

	| action agent |
	agent := MEGAgent named: 'Jugador N'.
	action := MEGCompanyMoveAction new.
	action agent: agent.
	self assert: action agent = agent.! !

!MEGCompanyMoveActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 11:15'!
test_04_SetCompany

	| action company |
	company := MEGCompany named: 'Los Faccioneros'.
	action := MEGCompanyMoveAction new.
	action company: company.
	self assert: action company = 'Los Faccioneros'.! !

!MEGCompanyMoveActionTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 17:12'!
test_05_SetDestination

	| action destination |
	destination := MEGSite named: 'Moria'.
	action := MEGCompanyMoveAction new.
	action destination: destination.
	self assert: action destination = destination.! !

TestCase subclass: #MEGCompanyMoveTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Collaboration'!

!MEGCompanyMoveTest methodsFor: 'public' stamp: 'SergioFedi 6/21/2016 10:29'!
test_01_MoveCompanyOk
	| action world origin result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Frodo Solo'.
	action := MEGCompanyMoveAction world: world.
	origin := (world siteNamed: 'Bag End').
	action agent: (world agentNamed: 'Jugador 1').
	action company: 'Frodo Solo'.
	action destination: 'Rivendell'.

	self assert: (action agent companyNamed: action company) site name = 'Bag End'.
	self assert: origin occupants size = 1.
	self assert: (world siteNamed: action destination) occupants size = 0.
	result := action perform.
	self assert: (action agent companyNamed: action company) site name = 'Rivendell'.
	self assert: origin occupants size = 0.
	self assert: (world siteNamed: action destination) occupants size = 1.
	
	self assert: result isSuccess.
! !

TestCase subclass: #MEGCompanyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGCompanyTest commentStamp: '<historical>' prior: 0!
A MEGCompanyTest is a test class for testing the behavior of MEGCompany!

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:12'!
test_01_Defaults

	| company |
	company := MEGCompany new.
	self assert: company agent isNil.
	self assert: company isAvailable.
	self assert: company isEmpty.
	self assert: company isUnavailable not.
	self assert: company members isEmpty.
	self assert: company name = nil.
	self assert: company notEmpty not.
	self assert: company reasonForBeingUnavailable isNil.
	self assert: company site isNil.
	self assert: company size = 0.
! !

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/15/2016 23:19'!
test_02_Creation

	| company |
	company := MEGCompany named: 'Company of the Ring'.
	self assert: company name = 'Company of the Ring'.! !

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/15/2016 23:25'!
test_03_AddMember

	| company |
	company := MEGCompany named: 'Company of the Ring'.
	company addMember: (MEGCharacter named: 'Frodo' homeSiteNamed: 'Bag End').
	self assert: company size = 1.! !

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/15/2016 23:26'!
test_04_Includes

	| company character |
	company := MEGCompany named: 'Company of the Ring'.
	character := (MEGCharacter named: 'Frodo' homeSiteNamed: 'Bag End').
	company addMember: character.
	self assert: (company includes: character).! !

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:25'!
test_05_ReasonForBeingUnavailableNotNil

	| company |
	company := MEGCompany new.
	company reasonForBeingUnavailable: 'Testing'.
	self assert: company isAvailable not.
	self assert: company isUnavailable.
	self assert: company reasonForBeingUnavailable notNil.
! !

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 11:38'!
test_06_Agent

	| company agent character |
	company := MEGCompany named: 'Company of the Ring'.
	agent := (MEGAgent named: 'Jugador 1').
	character := (MEGCharacter named: 'Frodo' homeSiteNamed: 'Bag End').
	agent influence: character.
	self assert: company agent isNil.
	company addMember: character.
	self assert: company agent = agent.
! !

!MEGCompanyTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 14:22'!
test_07_BecomeAvailable

	| company |
	company := MEGCompany named: 'Company of the Ring'.
	company reasonForBeingUnavailable: 'Testing'.
	self assert: company isAvailable not.
	self assert: company isUnavailable.
	company becomeAvailable.
	self assert: company isAvailable.
	self assert: company isUnavailable not.
	self assert: company reasonForBeingUnavailable isNil.
! !

TestCase subclass: #MEGMaintenance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Roadmap'!

!MEGMaintenance methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/24/2016 16:46'!
integrationCollaboration_Done

	| tasks |
	tasks := OrderedCollection new.
	tasks add: '
MEGAgent >> makeAllXYZButCompaniesAvailable
MEGAgent >> move:to:
'.
	tasks add: '
influenceDirectly: cambiarlo a influence:
Cambiar XYZ a influenced
Que cuando haces que alguien influya directamente a alguien, que le defina su follower
'.
	tasks add: '
Eliminamos la variable de followers, que lo que hacia es tener a todos los influenciados por el agente (es decir, tenia todo el arbol de influenciados).
En cambio dejamos el metodo followers pero que calcula este arbol de influenciados.
Tambien eliminamos el metodo addFollower que terminaba quedando redundante'.
	^tasks.
! !

!MEGMaintenance methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/24/2016 16:45'!
integrationCollaboration_ToDo

	^'
MEGAgent >> recruit*
Testear en el recruit una compañia que no es vacia y no es del Agente
Testear que todos los miembros de una compania tengan el mismo site
Testear que la relacion de conocimiento de la compania sea ida y vuelta con los miembros
Testear Que quien mueva sea el Agent de los personajes de la company
Testear que el lugar al que mueven sea adyacente/reachable
Testear que el mensaje recruit y mover del agent devuelvan un result
Agregar tests y funcionalidad de que cuando cargamos a los hobbits, le sacamos que puedan spawnear en Rivendell
MEGCompany>>moveTo:
HomeSiteCriteria>>includes:inWorld:
MEGCharacter >> isHomeSite:
MEGCharacter >> moveTo:
MEGCompany >> moveTo:
MEGCompanyMoveAction >> perform (bocha de escenarios)
MEGRecruitFactionAction >> perform (bocha de escenarios)
'! !

!MEGMaintenance methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/24/2016 16:08'!
unit_Done

	| tasks |
	tasks := OrderedCollection new.
	tasks add: '
MEGRecruitCharacterAction >> company:
MEGRecruitCharacterAction >> companyToUse
MEGRecruitCharacterAction >> influencer
'.
	tasks add: '
MEGWorld >> addFactions:
MEGCharacter>>company
MEGCharacter>>companyForCharacterUnderYourInfluence
'.
	tasks add: '
Test MEGCompany>>agent'.
	tasks add: 'Add test to MEGSite>>addOccupant
Add test to MEGSite>>removeOccupant
Add test to MEGSite>>includesOccupant: y remover referencias a occupants
'.
	^tasks.
! !

!MEGMaintenance methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/24/2016 16:08'!
unit_ToDo

	^'
'! !

TestCase subclass: #MEGRecruitCharacterActionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGRecruitCharacterActionTest commentStamp: '<historical>' prior: 0!
A MEGRecruitCharacterActionTest is a test class for testing the behavior of MEGRecruitCharacterAction!

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/14/2016 17:35'!
test_01_Defaults

	| action |
	action := MEGRecruitCharacterAction new.
	self assert: action recruitee isNil.
	self assert: action recruiter isNil.
	self assert: action site isNil.
	self assert: action world isNil.
	self assert: action company isNil.
	self assert: action directInfluencer isNil.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:25'!
test_02_ConstructorMethod

	| world action |
	world := MEGWorld new.
	action := MEGRecruitCharacterAction world: world.
	self assert: action world = world.
	! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:22'!
test_03_SetRecrutee

	| action recrutee |
	recrutee := MEGCharacter named: 'Rambo' homeSiteNamed: 'Arizona'.
	action := MEGRecruitCharacterAction new.
	action recruitee: recrutee.
	self assert: action recruitee = recrutee.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/14/2016 17:36'!
test_04_SetRecruiter

	| action recruiter |
	recruiter := MEGAgent named: 'US Army'.
	action := MEGRecruitCharacterAction new.
	action recruiter: recruiter.
	self assert: action recruiter = recruiter.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:22'!
test_05_SetSite

	| action site |
	site := MEGSite named: 'Hope, Washington'.
	action := MEGRecruitCharacterAction new.
	action site: site.
	self assert: action site = site.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 15:26'!
test_06_DirectInfluencer

	| action directInfluencer |
	directInfluencer := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	action := MEGRecruitCharacterAction new.
	action directInfluencer: directInfluencer.
	self assert: action directInfluencer = directInfluencer.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 15:26'!
test_07_SetCompanyAsObject

	| action character company |
	character := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	company := MEGCompany named: 'Solo Loco'.
	action := MEGRecruitCharacterAction new.
	action company: company.
	self assert: action company = company.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 15:27'!
test_08_SetCompanyAsStringNotFound

	| action character company |
	character := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	company := 'Solo Loco'.
	action := MEGRecruitCharacterAction new.
	action recruiter: (MEGAgent named: 'Jugador Solitario').
	action company: company.
	self assert: action company name = 'Solo Loco'.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 15:33'!
test_09_SetCompanyAsStringAlreadyExisting

	| action  company |
	action := MEGRecruitCharacterAction world:
		(MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Solo Loco').
	action recruiter: (action world agentNamed: 'Jugador 1').
	company := action recruiter companyNamed: 'Solo Loco'.
	action company: 'Solo Loco'.
	self assert: action company = company.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 15:40'!
test_10_CompanyToUse

	| action companyExpected |
	action := MEGRecruitCharacterAction world:
		(MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Solo Loco').
		
	action directInfluencer: (action world characterNamed: 'Frodo').
	companyExpected := (action world agentNamed: 'Jugador 1') companyNamed: 'Solo Loco'.
	action company: nil.
	
	self assert: action companyToUse = companyExpected.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 16:07'!
test_11_Influencer

	| action  |
	action := MEGRecruitCharacterAction world:
		(MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Solo Loco').

	self assert: action influencer isNil.
	action recruiter: (action world agentNamed: 'Jugador 1').
	self assert: action influencer = action recruiter.
	action directInfluencer: (action world characterNamed: 'Frodo').
	self assert: action influencer = action directInfluencer.
! !

TestCase subclass: #MEGRecruitCharacterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Collaboration'!

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:44'!
test_01_RecruitUnderGeneralInfluenceInNewCompany
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action company: (MEGCompany named: 'Frodo FTW').
	self assert: action recruiter followers isEmpty.
	self assert: action recruitee characterFollowed isNil.
	self assert: action recruitee agentFollowed isNil.
	self assert: action recruitee currentSite isNil.
	self assert: (action site includesOccupant: action recruitee) not.
	self assert: action recruiter companies isEmpty.
	self assert: action recruitee company isNil.
	result := action perform.
	self assert: action recruiter followers notEmpty.
	self assert: action recruitee characterFollowed = action recruiter.
	self assert: action recruitee agentFollowed = action recruiter.
	self assert: action recruitee currentSite = action site.
	self assert: (action site includesOccupant: action recruitee).
	self assert: action recruiter companies notEmpty.
	self assert: action recruiter companies first = action recruitee company.
	self assert: action recruitee company name = 'Frodo FTW'.
	self assert: action recruitee company size = 1.
	self assert: (action recruitee company includes: action recruitee).
	self assert: result isSuccess.! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:38'!
test_02_RecruitUnderGeneralInfluenceSiteMissing
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: nil.
	action company: 'Frodo Solo'.
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:50'!
test_03_RecruitUnderGeneralInfluenceRecruiterMissing
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: nil.
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action company: MEGCompany new.
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:43'!
test_04_RecruitUnderGeneralInfluenceRecruteeMissing
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: nil.
	action site: (world siteNamed: 'Bag End').
	action company: 'Frodo Solo'.
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:39'!
test_05_RecruitUnderGeneralInfluenceWorldMissing
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action company: 'Frodo Solo'.
	action world: nil.
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:50'!
test_06_RecruitUnderGeneralInfluenceSiteFromOtherWorld
	| action world anotherWorld result |
	world := MEGWorldFactory new newWorld.
	anotherWorld := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (anotherWorld siteNamed: 'Bag End').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:50'!
test_07_RecruitUnderGeneralInfluenceRecruiterFromOtherWorld
	| action world anotherWorld result |
	world := MEGWorldFactory new newWorld.
	anotherWorld := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (anotherWorld agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:50'!
test_08_RecruitUnderGeneralInfluenceRecruiteeFromOtherWorld
	| action world anotherWorld result |
	world := MEGWorldFactory new newWorld.
	anotherWorld := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (anotherWorld characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:51'!
test_09_RecruitUnderGeneralInfluenceNonHomeSite
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Moria').
	self assert: action recruitee currentSite isNil.
	result := action perform.
	self assert: action recruitee currentSite isNil.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:51'!
test_10_RecruitUnderGeneralInfluenceNotEnoughInfluence
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruiter baseInfluence: 8.
	action recruitee: (world characterNamed: 'Elrond').
	action site: (world siteNamed: 'Rivendell').
	result := action perform.
	self assert: action recruiter currentInfluence = 8.
	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:51'!
test_11_RecruitUnderGeneralInfluenceAlreadyRecruited
	| action world result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 2'.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/14/2016 18:34'!
test_12_RecruitUnderGeneralInfluenceOkAllParametersAreStrings
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: 'Jugador 1'.
	action recruitee: 'Frodo'.
	action site: 'Bag End'.
	action company: 'Frodo Solo'.
	result := action perform.

	self assert: result isSuccess.! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:44'!
test_13_RecruitUnderDirectInfluenceOk
	| action world  result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 1' inCompany: 'Gandalf Rocks'.
	(world characterNamed: 'Gandalf') currentSite: (world siteNamed: 'Bag End').
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action directInfluencer: (world characterNamed: 'Gandalf').
	self assert: (action recruiter followers includes: action recruitee) not.
	self assert: action recruitee characterFollowed isNil.
	self assert: action recruitee agentFollowed isNil.
	self assert: action recruitee currentSite isNil.
	self assert: (action site includesOccupant: action recruitee) not.
	self assert: action recruiter companies size = 1.
	self assert: action recruitee company isNil.
	result := action perform.
	self assert: result isSuccess.
	self assert: (action recruiter followers includes: action recruitee).
	self assert: action recruitee characterFollowed = action directInfluencer.
	self assert: action recruitee agentFollowed = action recruiter.
	self assert: action recruitee currentSite = action site.
	self assert: (action site includesOccupant: action recruitee).
	self assert: action recruiter companies size = 1.
	self assert: action recruitee company = action directInfluencer company.
	self assert: action recruitee company name = 'Gandalf Rocks'.
	self assert: action recruitee company size = 2.
	self assert: (action recruitee company includes: action recruitee).
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 17:03'!
test_14_RecruitUnderDirectInfluenceDirectInfluencerFromOtherWorld
	| action world anotherWorld result |
	world := MEGWorldFactory new newWorld.
	anotherWorld := MEGWorldFactory new newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 1'.
	(anotherWorld characterNamed: 'Gandalf') currentSite: (world siteNamed: 'Bag End').
	(anotherWorld characterNamed: 'Gandalf') characterFollowed: (world agentNamed: 'Jugador 1').
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action directInfluencer: (anotherWorld characterNamed: 'Gandalf').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 17:04'!
test_15_RecruitUnderDirectInfluenceNotEnoughInfluence
	| action world  result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Sam Gamgee' at: 'Bag End' for: 'Jugador 1'.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action directInfluencer: (world characterNamed: 'Sam Gamgee').
	self assert: action recruitee characterFollowed isNil.
	result := action perform.
	self assert: action recruitee characterFollowed isNil.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 18:04'!
test_16_RecruitUnderDirectInfluenceDirectInfluencerNotFollowingSameAgent
	| action world  result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 2'.
	(world characterNamed: 'Gandalf') currentSite: (world siteNamed: 'Bag End').
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action directInfluencer: (world characterNamed: 'Gandalf').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 2.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 14:06'!
test_17_RecruitUnderDirectInfluenceDirectInfluencerNotOnSameSite
	| action world  result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 1'.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action directInfluencer: (world characterNamed: 'Gandalf').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 2.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:51'!
test_18_RecruitUnderGeneralInfluenceCompanyMissing
	| action world result |
	world := MEGWorldFactory new newWorld.
	action := MEGRecruitCharacterAction world: world.
	
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action company: nil.
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:44'!
test_19_RecruitUnderGeneralInfluenceInExistingCompany
	| action world result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Frodo The Explorer'.
	action := MEGRecruitCharacterAction world: world.
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Sam Gamgee').
	action site: (world siteNamed: 'Bag End').
	action company: 'Frodo The Explorer'.
	self assert: action recruiter followers size = 1.
	self assert: action recruitee characterFollowed isNil.
	self assert: action recruitee agentFollowed isNil.
	self assert: action recruitee currentSite isNil.
	self assert: (action site includesOccupant: action recruitee) not.
	self assert: action recruiter companies size = 1.
	self assert: action recruitee company isNil.
	result := action perform.
	self assert: result isSuccess.
	self assert: action recruiter followers size = 2.
	self assert: action recruitee characterFollowed = action recruiter.
	self assert: action recruitee agentFollowed = action recruiter.
	self assert: action recruitee currentSite = action site.
	self assert: (action site includesOccupant: action recruitee).
	self assert: action recruiter companies size = 1.
	self assert: action recruiter companies first = action recruitee company.
	self assert: action recruitee company name = 'Frodo The Explorer'.
	self assert: action recruitee company size = 2.
	self assert: (action recruitee company includes: action recruitee).
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:04'!
test_20_SetCompanyAsStringWhenItAlreadyExists

	| action company |
	action := MEGRecruitCharacterAction world: (MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Viajeros').
	action recruiter: (action world agentNamed: 'Jugador 1').
	company := action recruiter companyNamed: 'Viajeros'.
	self assert: action company isNil.
	action company: 'Viajeros'.
	self assert: action company = company.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:22'!
test_21_SetCompanyAsStringWhenItsNew

	| action  |
	action := MEGRecruitCharacterAction world: MEGWorldFactory new newWorld.
	action recruiter: (action world agentNamed: 'Jugador 1').
	self assert: action company isNil.
	action company: 'Viajeros'.
	self assert: action company name = 'Viajeros'.! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 16:30'!
test_22_SetCompanyAsObject

	| action |
	action := MEGRecruitCharacterAction new.
	action company: (MEGCompany named: 'Easy Company').
	self assert: action company name = 'Easy Company'.! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/16/2016 18:11'!
test_23_RecruitUnderGeneralInfluenceInMisplacedCompany
	| action world result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Frodo The Explorer'.
	action := MEGRecruitCharacterAction world: world.

	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Elrond').
	action site: (world siteNamed: 'Rivendell').
	action company: 'Frodo The Explorer'.
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.
! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 03:49'!
test_24_RecruitUnderGeneralInfluenceWithExistingCompanyName
	| action world result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Frodo' at: 'Bag End' for: 'Jugador 1' inCompany: 'Frodo The Explorer'.
	action := MEGRecruitCharacterAction world: world.

	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Sam Gamgee').
	action site: (world siteNamed: 'Bag End').
	action company: (MEGCompany named: 'Frodo The Explorer').
	result := action perform.

	self assert: result isSuccess not.
	self assert: result errors size = 1.! !

!MEGRecruitCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 17:57'!
test_25_RecruitUnderGeneralInfluenceInCompanyFromOtherAgent
	| action world result |
	world := MEGWorldFactory new newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 2' inCompany: 'Gandalf Rocks'.
	(world characterNamed: 'Gandalf') currentSite: (world siteNamed: 'Bag End').
	action := MEGRecruitCharacterAction world: world.
	action recruiter: (world agentNamed: 'Jugador 1').
	action recruitee: (world characterNamed: 'Frodo').
	action site: (world siteNamed: 'Bag End').
	action company: ((world agentNamed: 'Jugador 2') companyNamed: 'Gandalf Rocks').
	result := action perform.
	self assert: result isSuccess not.
	self assert: result errors size = 1.
	self assert: (result errors first beginsWith: 'Jugador 1 is trying to recruit a character in a company the belongs to other agent (Jugador 2)').
! !

TestCase subclass: #MEGRecruitFactionActionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGRecruitFactionActionTest commentStamp: '<historical>' prior: 0!
A MEGRecruitFactionActionTest is a test class for testing the behavior of MEGRecruitFactionAction!

!MEGRecruitFactionActionTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:21'!
test_01_Defaults

	| action |
	action := MEGRecruitFactionAction new.
	self assert: action characterName isNil.
	self assert: action factionName isNil.
	self assert: action randomNumberGenerator isNil.
	self assert: action recruiter isNil.
	self assert: action world isNil.
! !

!MEGRecruitFactionActionTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:23'!
test_02_ConstructorMethod

	| world action |
	world := MEGWorld new.
	action := MEGRecruitFactionAction world: world.
	self assert: action world = world.
	! !

!MEGRecruitFactionActionTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:25'!
test_03_SetCharacterName

	| action  |
	action := MEGRecruitFactionAction new.
	action characterName: 'Gandalf'.
	self assert: action characterName = 'Gandalf'.! !

!MEGRecruitFactionActionTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:25'!
test_04_SetFactionName

	| action  |
	action := MEGRecruitFactionAction new.
	action factionName: 'Hobbits'.
	self assert: action factionName = 'Hobbits'.! !

!MEGRecruitFactionActionTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:27'!
test_05_SetRandomNumberGenerator

	| action stream |
	action := MEGRecruitFactionAction new.
	stream := ReadStream on: #(4 3 2 1).
	action randomNumberGenerator: [stream next].
	self assert: action randomNumberGenerator value = 4.
	self assert: action randomNumberGenerator value = 3.
	self assert: action randomNumberGenerator value = 2.
	self assert: action randomNumberGenerator value = 1.
! !

!MEGRecruitFactionActionTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:23'!
test_06_SetRecruiter

	| action recruiter |
	recruiter := MEGAgent named: 'US Army'.
	action := MEGRecruitFactionAction new.
	action recruiter: recruiter.
	self assert: action recruiter = recruiter.! !

TestCase subclass: #MEGResourceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGResourceTest commentStamp: '<historical>' prior: 0!
A MEGResourceTest is a test class for testing the behavior of MEGResource!

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 13:59'!
test_01_Defaults

	| resource |
	resource := MEGResource new.
	self assert: resource agentFollowed isNil.
	self assert: resource description isNil.
	self assert: resource marshallingPoints isZero.
	self assert: resource name isNil.
	self assert: resource recruitment isNil.
	self assert: resource resourceClass isNil.
	! !

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:01'!
test_02_SetAgent

	| resource agent |
	resource := MEGResource new.
	agent := MEGAgent new.
	resource agentFollowed: agent.
	self assert: resource agentFollowed = agent.
	! !

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:04'!
test_03_SetDescription

	| resource  |
	resource := MEGResource new.
	resource description: 'Test resource'.
	self assert: resource description = 'Test resource'.
	! !

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:04'!
test_04_SetMarshallingPoints

	| resource  |
	resource := MEGResource new.
	resource marshallingPoints: 8.
	self assert: resource marshallingPoints = 8.
	! !

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:06'!
test_05_SetName

	| resource  |
	resource := MEGResource new.
	resource name: 'Faction'.
	self assert: resource name = 'Faction'.
	! !

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:08'!
test_06_SetRecruitment

	| resource object |
	resource := MEGResource new.
	object:= Object new.
	resource recruitment: object.
	self assert: resource recruitment = object.
	! !

!MEGResourceTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 14:10'!
test_07_SetResourceClass

	| resource object |
	resource := MEGResource new.
	object:= Object new.
	resource resourceClass: object.
	self assert: resource resourceClass = object.
	! !

TestCase subclass: #MEGResourcesFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGResourcesFactoryTest commentStamp: '<historical>' prior: 0!
A MEGResourcesFactoryTest is a test class for testing the behavior of MEGResourcesFactory!

!MEGResourcesFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:54'!
test_01_NewFactions

	| factions |
	factions := MEGResourcesFactory new newFactions.
	self assert: factions size = 29.! !

TestCase subclass: #MEGRoadmap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Roadmap'!

!MEGRoadmap commentStamp: 'SergioFedi 6/23/2016 10:40' prior: 0!
Esta clase la usamos para listar las features que vamos a implementar!

!MEGRoadmap methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/24/2016 14:06'!
done

	| tasks |
	tasks := OrderedCollection new.
	tasks add: '
Modelar la fase de untap
Enderezar a todos los personajes (sans heridos que no tenemos)
La companía queda unavailable (pero cuando se mueve la ponemos available)
'.
	^tasks.
! !

!MEGRoadmap methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/24/2016 11:19'!
nextAction

	^'
	'! !

!MEGRoadmap methodsFor: 'as yet unclassified' stamp: 'SergioFedi 6/23/2016 10:39'!
somedayMaybe

	^'
Modelar los ataques automáticos en los sites
	Strikes y cómo se targetean
	Tappear personajes
	Resolver strikes (vencerlos / ser vencido)
 	Herir personajes
Modelar curarse
	Modelar curarse en Haven
Modelar el path recorrido al moverse
Modelar hazard creatures
Modelar tener items
Modelar guardar items
Modelar mover items de un personaje a otro
	'! !

TestCase subclass: #MEGSiteFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGSiteFactoryTest commentStamp: '<historical>' prior: 0!
A MEGSiteFactoryTest is a test class for testing the behavior of MEGSiteFactory!

!MEGSiteFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:21'!
test_01_NewSites

	| sites |
	sites := MEGSiteFactory new newSites.
	self assert: sites notEmpty.
	! !

!MEGSiteFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:21'!
test_02_NewSiteNamed

	| site |
	site := MEGSiteFactory new newSiteNamed: 'Lorien'.
	self assert: site notNil.
	! !

TestCase subclass: #MEGSiteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGSiteTest commentStamp: '<historical>' prior: 0!
A MEGSiteTest is a test class for testing the behavior of MEGSite!

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:30'!
test_01_Defaults

	| site |
	site := MEGSite new.
	self assert: site name isNil.
	self assert: site occupants isEmpty.
	self assert: site type isNil.! !

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:17'!
test_02_Creation

	| site |
	site := MEGSite named: 'Dol-Amroth'.
	self assert: site name = 'Dol-Amroth'.
	self assert: site type isNil.! !

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:36'!
test_03_AddOccupant

	| site character |
	site := MEGSite new.
	character := MEGCharacter new.
	site addOccupant: character.
	self assert: site occupants notEmpty.
	self assert: site occupants first = character.
	self assert: character currentSite isNil.! !

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:37'!
test_04_RemoveOccupant

	| site character |
	site := MEGSite new.
	character := MEGCharacter new.
	site addOccupant: character.
	site removeOccupant: character.
	self assert: site occupants isEmpty.
	self assert: character currentSite isNil.! !

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:41'!
test_05_IncludesOccupant

	| site character |
	site := MEGSite new.
	character := MEGCharacter new.
	self deny: (site includesOccupant: character).
	site addOccupant: character.
	self assert: (site includesOccupant: character).
! !

TestCase subclass: #MEGWorldFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGWorldFactoryTest commentStamp: '<historical>' prior: 0!
A MEGWorldFactoryTest is a test class for testing the behavior of MEGWorldFactory!

!MEGWorldFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:39'!
test_01_newWorld

	self assert: MEGWorldFactory new newWorld notNil.! !

TestCase subclass: #MEGWorldTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGWorldTest commentStamp: '<historical>' prior: 0!
A MEGWorldTest is a test class for testing the behavior of MEGWorld!

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/21/2016 10:26'!
test_01_Creation

	| world |
	world := MEGWorld new.
	self assert: world locations isEmpty.
	self assert: world characters isEmpty.
	self assert: world agents isEmpty.
	self assert: world factions isEmpty.! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:43'!
test_02_AddSite

	| world |
	world := MEGWorld new.
	world addSite: (MEGSite named: 'Lorien').
	self assert: world locations notEmpty.
	self assert: world locations size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:47'!
test_03_AddCharacter

	| world |
	world := MEGWorld new.
	world addSite: (MEGSiteFactory new newSiteNamed: 'Bag End').
	world addCharacter: (MEGCharacter named: 'Frodo' homeSiteNamed: 'Bag End').
	self assert: world characters notEmpty.
	self assert: world characters size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:23'!
test_04_RetrieveSite

	| world  |
	world := MEGWorld new.
	self should: [world siteNamed: 'Rivendell'] raise: NotFound.
	world addSite: (MEGSite named: 'Rivendell').
	self assert: (world siteNamed: 'Rivendell') notNil.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:50'!
test_05_RetrieveCharacter

	| world  |
	world := MEGWorld new.
	world addSite: (MEGSiteFactory new newSiteNamed: 'Edoras').
	self should: [world characterNamed: 'Eowyn'] raise: NotFound.
	world addCharacter: (MEGCharacter named: 'Eowyn' homeSiteNamed: 'Edoras').
	self assert: (world characterNamed: 'Eowyn') notNil.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:44'!
test_06_AddAgent

	| world |
	world := MEGWorld new.
	world addAgent: (MEGAgent named: 'Player 1').
	self assert: world agents notEmpty.
	self assert: world agents size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:45'!
test_07_AgentNamed

	| world |
	world := MEGWorld new.
	world addAgent: (MEGAgent named: 'Player 1').
	self assert: (world agentNamed: 'Player 1') notNil.
	self assert: (world agentNamed: 'Player 1') name = 'Player 1'.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:48'!
test_08_AddSites

	| world sites |
	world := MEGWorld new.
	sites := OrderedCollection
		with: (MEGSiteFactory new newSiteNamed: 'Bag End')
		with: (MEGSiteFactory new newSiteNamed: 'Lorien')
		with: (MEGSiteFactory new newSiteNamed: 'Lossadan Camp')
		with: (MEGSiteFactory new newSiteNamed: 'Moria').
	world addSites: sites.
	self assert: world locations notEmpty.
	self assert: world locations size = 4.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/19/2016 19:42'!
test_09_AddCharacters

	| world characters |
	world := MEGWorld new.
	world addSite: (MEGSiteFactory new newSiteNamed: 'Bag End').
	world addSite: (MEGSiteFactory new newSiteNamed: 'Rivendell').
	characters := OrderedCollection
		with: (MEGCharacterFactory new newCharacterNamed: 'Bilbo')
		with: (MEGCharacterFactory new newCharacterNamed: 'Frodo')
		with: (MEGCharacterFactory new newCharacterNamed: 'Merry')
		with: (MEGCharacterFactory new newCharacterNamed: 'Pippin').
	world addCharacters: characters.
	self assert: world characters notEmpty.
	self assert: world characters size = 4.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:33'!
test_10_AddFaction

	| world |
	world := MEGWorld new.
	world addFaction: MEGResource new.
	self assert: world factions notEmpty.
	self assert: world factions size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:37'!
test_11_FactionNamed

	| world faction |
	world := MEGWorld new.
	faction := MEGResource new.
	faction name: 'Test Faction'.
	world addFaction: faction.
	self assert: (world factionNamed: 'Test Faction') = faction.
	
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 15:12'!
test_12_AddFactions

	| world factions |
	world := MEGWorld new.
	factions := OrderedCollection with: MEGResource new with: MEGResource new with: MEGResource new.
	world addFactions: factions.
	self assert: world factions notEmpty.
	self assert: world factions size = 3.
! !

TestCase subclass: #ResultTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!ResultTest commentStamp: '<historical>' prior: 0!
A ResultTest is a test class for testing the behavior of Result!

!ResultTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:02'!
test_01_Defaults

	| result |
	result := Result new.
	self deny: result hasErrors.
	self assert: result isSuccess.
	self assert: result errors isEmpty.
	self assert: result object isNil.! !

!ResultTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:05'!
test_02_AddError

	| result |
	result := Result new.
	result addError: 'Test has not passed'.
	self assert: result hasErrors.
	self assert: result isSuccess not.
	self assert: result errors notEmpty.
	self assert: result object isNil.! !

!ResultTest methodsFor: 'public' stamp: 'SergioFedi 6/22/2016 12:05'!
test_03_SetObject

	| result object |
	result := Result new.
	object := Object new.
	result object: object.
	self assert: result object = object.
	self assert: result isSuccess.
! !

TestCase subclass: #TheCompanyFormsAtRivendel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Collaboration'!

!TheCompanyFormsAtRivendel methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 11:52'!
newWorld

	| world |
	world := MEGWorldFactory new newWorld.	
	^world.! !

!TheCompanyFormsAtRivendel methodsFor: 'private' stamp: 'SergioFedi 6/14/2016 16:32'!
newWorldWithCharacterPlayed: aString at: aString2 for: aString3

	^ MEGWorldFactory new newWorldWithCharacterPlayed: aString at: aString2 for: aString3.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:43'!
test_01_WizardRecruitsGandalf
	| world rivendel gandalf wizard |
	world := self newWorld.
	rivendel := world siteNamed: 'Rivendell'.
	gandalf := world characterNamed: 'Gandalf'.
	wizard := world agentNamed: 'Jugador 1'.
	self assert: gandalf characterFollowed isNil.
	self assert: gandalf currentSite isNil.
	self deny: (wizard followers includes: gandalf).
	self deny: (rivendel includesOccupant: gandalf).
	self assert: wizard currentGeneralInfluence = 20.
	wizard recruit: gandalf at: rivendel inCompany: MEGCompany new.
	self assert: gandalf characterFollowed = wizard.
	self assert: gandalf currentSite = rivendel.
	self assert: (wizard followers includes: gandalf).
	self assert: (rivendel includesOccupant: gandalf).
	self assert: wizard currentGeneralInfluence = 20! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:43'!
test_02_WizardRecruitsElrondIntoGeneralInfluence
	| world rivendel elrond wizard |
	world := self newWorld.
	rivendel := world siteNamed: 'Rivendell'.
	elrond := world characterNamed: 'Elrond'.
	wizard := world agentNamed: 'Jugador 1'.
	self assert: elrond characterFollowed isNil.
	self assert: elrond currentSite isNil.
	self deny: (wizard followers includes: elrond).
	self deny: (rivendel includesOccupant: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	wizard recruit: elrond at: rivendel inCompany: MEGCompany new.
	self assert: elrond agentFollowed = wizard.
	self assert: elrond currentSite = rivendel.
	self assert: (wizard followers includes: elrond).
	self assert: (rivendel includesOccupant: elrond).
	self assert: wizard currentGeneralInfluence = 10! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/23/2016 17:43'!
test_03_WizardRecruitsElrondIntoGandalfsInfluence

	| world rivendel gandalf elrond wizard |
	world := self newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 1'.
	rivendel := world siteNamed: 'Rivendell'.
	gandalf := world characterNamed: 'Gandalf'.
	elrond := world characterNamed: 'Elrond'.
	wizard := world agentNamed: 'Jugador 1'.
	
	self assert: elrond characterFollowed isNil.
	self assert: elrond currentSite isNil.
	self deny: (wizard followers includes: elrond).
	self deny: (rivendel includesOccupant: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	self assert: gandalf currentDirectInfluence = 10.
	wizard recruit: elrond at: rivendel under: gandalf.
	self assert: (elrond characterFollowed) = gandalf.
	self assert: (elrond agentFollowed) = wizard.
	self assert: (elrond currentSite) = rivendel.
	self assert: (gandalf influenced includes: elrond).
	self assert: (rivendel includesOccupant: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	self assert: gandalf currentDirectInfluence = 0.! !

Object subclass: #MEGElementFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

MEGElementFactory subclass: #MEGCharacterFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/23/2016 16:58'!
characterFromLine: line
	| character fields homeSite |
	"1- NAME
	 2- TYPE
	 3- RARITY
	 4- RACE
	 5- SKILLS
	 6- HOME_SITE
	 7- MP
	 8- MIND
	 9- INFLUENCE
	10- PROWESS
	11- BODY
	12- CORRUPTION
	13- ARTIST
	14- RANDOM#
	15- |DESCRIPTION|"
	
	fields := line substrings: #($,).
	character := MEGCharacter new.
	character name: fields first.
	homeSite := self homeSiteFrom: fields sixth.
	character homeSiteCriteria: homeSite.
	character marshallingPoints: (fields at: 7) asNumber.
	character mind: (fields at: 8) asNumber.
	character baseInfluence: (fields at: 9) asNumber.
	^character.! !

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 22:04'!
charactersFromString: aString

	^aString lines collect: [ :line | self characterFromLine: line ].! !

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/19/2016 19:39'!
homeSiteFrom: aString

	(aString beginsWith: 'Any ') 
		ifTrue:  [ | type |
			type := aString allButFirst: 4.
			(type = 'Haven')
				ifTrue: [ ^HomeSiteCriteria type: type ]
				ifFalse: [ self error: 'Homesite criteria for type other than Haven' ]
		]
		ifFalse: [ ^HomeSiteCriteria named: aString named: 'Rivendell'].
	! !

!MEGCharacterFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:58'!
newCharacterNamed: aString

	^self newCharacters detect: [:each | each name = aString].! !

!MEGCharacterFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:03'!
newCharacters

	^self charactersFromString: self spoilerString.! !

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 22:34'!
spoilerString

	^'Adrazar,Character,F1,Dunadan,Scout/Diplomat,Dol Amroth,1,3,1,3,6,0,David Dettrick,2,|Unique.  +1 direct influence against all factions.|
Alatar,Character,F2,Wizard,Warrior/Scout/Ranger/Sage,Edhellond,0,0,10,6,9,0,Angus McBride,10,|Unique. During the movement/hazard phase, the number of cards that opponent draws based on Alatar''s company''s movement is reduced by one.  If in a Haven when a hazard creature is played on another company, he may join tha company and face one of the hazard creature''s strikes; he must tap and make a corruption check immediately following the attack.|
Anborn,Character,U,Dunadan,Scout/Ranger,Pelargir,0,2,0,2,8,0,David Dettrick,10,|Unique.  +2 direct influence against the Men of Lebennin faction.|
Annalena,Character,F2,Elf,Scout/Sage,Edhellond,1,3,0,3,8,0,Angus McBride,9,|Unique.|
Aragorn II,Character,F1,Dunadan,Warrior/Scout/Ranger,Bree,3,9,3,6,9,0,Angus McBride,9,|Unique.  +2 direct influence against the Rangers of the North faction. -3 marshalling points if eliminated.|
Arinmir,Character,U,Elf,Sage/Diplomat,Edhellond,1,4,2,2,7,0,Angus McBride,9,|Unique.  +2 direct influence against the Variags faction.|
Arwen,Character,R,Elf,Scout/Sage,Rivendell,1,3,0,2,8,0,Angus McBride,9,|Unique.  +7 direct influence only usable against Aragorn II.|
Balin,Character,U,Dwarf,Warrior/Sage,Blue Mountain Dwarf-hold,2,5,2,4,7,0,Angelo Montanini,8,|Unique.  +2 prowess against Orcs.  +1 direct influence against Dwarves and Dwarf factions.|
Bard Bowman,Character,F2,Man,Warrior/Scout,Lake-town,0,2,0,3,6,0,Angelo Montanini,8,|Unique.  +2 direct influence against the Men of Northern Rhovanion faction.|
Barliman Butterbur,Character,U,Man,Warrior,Bree,0,1,0,2,6,0,April Lee,8,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Beorn,Character,F1,Man,Warrior/Ranger,Beorn''s House,2,7,2,7,9,0,Stefano Baldo,8,|Unique.  +2 direct influence against the Beornings faction.|
Beregond,Character,F1,Dunadan,Warrior,Minas Tirith,0,2,0,4,8,-1,Edward Beard, Jr.,8,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Beretar,Character,U,Dunadan,Warrior/Ranger,Bree,2,5,1,5,8,0,Angelo Montanini,7,|Unique.  +2 direct influence against the Rangers of the North faction.|
Bergil,Character,U,Dunadan,Scout,Minas Tirith,0,2,0,1,9,0,Stefano Baldo,7,|Unique.|
Bifur,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,2,0,4,7,0,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Bilbo,Character,R,Hobbit,Scout/Sage,Bag End,2,5,1,1,9,0,Angus McBride,7,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +4.  -2 marshalling points if eliminated.|
Bofur,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,2,0,4,7,0,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Bombur,Character,U,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,3,6,-1,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Boromir II,Character,F2,Dunadan,Warrior,Minas Tirith,1,4,1,6,7,-1,Angelo Montanini,6,|Unique.  +2 direct influence against the Men of Anorien faction. -1 to all of his corruption checks.|
Celeborn,Character,F1,Elf,Warrior/Sage,Lorien,2,6,1,6,9,0,Angus McBride,6,|Unique.  +5 direct influence that is only usable against Galadriel.|
Cirdan,Character,R,Elf,Warrior/Sage/Diplomat,Grey Havens,3,8,4,6,8,0,Quinton Hoover,6,|Unique.  When Cirdan is at Grey Havens, his controlling player may keep one more card than normal in his hand.  May tap to cancel one attack keyed to a Coastal Sea region.  +2 direct influence against the Elves of Lindon faction.  -3 marshalling points if eliminated.|
Dain II,Character,R,Dwarf,Warrior/Diplomat,Iron Hill Dwarf-hold,2,7,3,5,8,0,Angus McBride,6,|Unique.  +2 direct influence against Iron Hill Dwarves, +2 prowess against Orcs. +1 direct influence against Men and Man factions.|
Damrod,Character,U,Dunadan,Scout/Ranger,Vale of Erech,0,2,0,2,7,0,Mark Poole,6,|Unique.  +2 direct influence against the Men of Lamedon faction.|
Denethor II,Character,R,Dunadan,Warrior/Sage,Minas Tirith,1,4,2,3,6,0,Angus McBride,5,|Unique.  +2 direct influence against the Tower Guard of Minas Tirith faction.|
Dori,Character,U,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,3,6,-1,Angelo Montanini,5,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks agains factions.|
Dwalin,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,2,7,-1,Angelo Montanini,5,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Elladan,Character,F1,Elf,Warrior/Ranger,Rivendell,1,4,0,5,8,0,April Lee,5,|Unique.  +1 prowess against Orcs.|
Elrohir,Character,F1,Elf,Warrior/Ranger,Rivendell,1,4,0,5,8,0,April Lee,4,|Unique.  +1 prowess against Orcs.|
Elrond,Character,R,Elf,Warrior/Sage/Diplomat,Rivendell,3,10,4,7,9,0,Kevin Ward,4,|Unique.  When Elrond is at Rivendell, his controlling player may keep one more card than normal in his hand. -3 marshalling points if eliminated.|
Eomer,Character,U,Man,Warrior/Ranger,Edoras,1,3,0,3,8,0,Angelo Montanini,3,|Unique.  +2 direct influence against the Riders of Rohan faction.|
Eowyn,Character,U,Man,Warrior/Scout,Edoras,0,2,0,2,7,0,Angelo Montanini,3,|Unique.  Against Nazgul, +6 to her prowess, and his body is halved (round up).|
Erkenbrand,Character,F1,Man,Warrior,Edoras,1,4,2,5,6,0,Angus McBride,4,|Unique.  +2 direct influence against the Riders of Rohan faction.|
Faramir,Character,F1,Dunadan,Warrior/Ranger,Henneth Annun,2,5,1,5,8,0,Angelo Montanini,2,|Unique.  +2 direct influence against the Rangers of Ithilien faction.|
Fili,Character,U,Dwarf,Warrior/Scout,Blue Mountain Dwarf-hold,0,2,0,2,8,0,Angelo Montanini,12,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Forlong,Character,CB,Dunadan,Warrior,Minas Tirith,0,1,0,3,7,-1,Quinton Hoover,11,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Frodo,Character,R,Hobbit,Scout/Diplomat,Bag End,2,5,1,1,9,4,Angus McBride,11,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +4.  -2 marshalling points if eliminated.|
Galadriel,Character,R,Elf,Scout/Sage/Diplomat,Lorien,3,9,4,3,10,0,Angus McBride,10,|Unique.  When Galadriel is at Lorien, her controlling player may keep one more card than normal in his hand.  -3 marshalling points if eliminated.|
Galva,Character,R,Man,Scout/Sage/Diplomat,Shrel-Kain,1,4,1,0,9,0,Quinton Hoover,10,|Unique.  +2 direct influence against the Men of Dorwinion faction.  Against Nazgul, +6 to her prowess, and his body is halved (round up).|
Gamling the Old,Character,U,Man,Warrior,Edoras,0,2,1,3,7,0,Angus McBride,10,|Unique.|
Gandalf,Character,F2,Wizard,Warrior/Scout/Sage/Diplomat,Any Haven,0,0,10,6,9,1,Olivier Frot,9,|Unique.  All of his corruption checks are modified by +1.  Can tap to "test" a gold ring.|
Ghan-buri-Ghan,Character,U,Man,Scout/Ranger,Druadan Forest,2,5,2,2,9,0,April Lee,9,|Unique.  +2 direct influence against Wose factions.|
Gildor Inglorion,Character,F1,Elf,Warrior/Ranger,Rivendell,1,4,0,5,7,0,Lori Deitrick,9,|Unique.  +2 prowess against Orcs.|
Gimli,Character,F1,Dwarf,Warrior/Diplomat,Iron Hill Dwarf-hold,2,6,2,5,8,0,Lori Deitrick,9,|Unique.  +2 direct influence against Iron Hill Dwarves.  +2 prowess against Orcs.  +1 direct influence against Elves and Elf factions.|
Gloin,Character,U,Dwarf,Warrior/Diplomat,Blue Mountain Dwarf-hold,2,5,2,5,7,0,Angelo Montanini,8,|Unique.  +2 direct influence against Blue Mountain Dwarves. +1 prowess against Orcs.  +1 direct influence against Dwarves and Dwarf factions.|
Glorfindel II,Character,F1,Elf,Warrior/Sage,Rivendell,3,8,2,8,9,0,Randy Gallegos,8,|Unique.  +1 direct influence against Elves.|
Halbarad,Character,U,Dunadan,Sage/Diplomat,Cameth Brin,0,1,1,0,5,0,Quinton Hoover,8,|Unique.  +2 direct influence against the Hillmen faction.|
Haldalam,Character,R,Dunadan,Warrior/Diplomat,Shrel-Kain,2,5,1,4,9,0,David Deitrick,8,|Unique.  +4 direct influence against the Easterlings faction.|
Haldir,Character,U,Elf,Warrior,Lorien,1,3,0,4,8,0,Lori Deitrick,8,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Hama,Character,CB,Man,Warrior,Edoras,0,2,0,4,8,-1,Lori Deitrick,7,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Imrahil,Character,U,Dunadan,Warrior/Diplomat,Dol Amroth,2,6,2,5,8,0,Donato Giancola,7,|Unique.  +2 direct influence against the Knights of Dol Amroth faction.|
Kili,Character,F2,Dwarf,Warrior/Scout,Blue Mountain Dwarf-hold,1,3,0,3,8,-1,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Legolas,Character,U,Elf,Warrior/Diplomat,Thranduil''s Halls,2,6,2,5,8,0,Quinton Hoover,7,|Unique.  +2 direct influence against the Wood-elves faction.|
Mablung,Character,U,Dunadan,Warrior/Scout,Lond Galen,0,1,0,1,6,0,Margaret Organ-Keene,7,|Unique.  +2 direct influence against the Men of Anfalas faction.|
Merry,Character,U,Hobbit,Scout,Bag End,1,4,1,1,9,2,Angelo Montanini,7,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +2.|
Nori,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,2,0,4,7,0,Angelo Montanini,6,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Oin,Character,U,Dwarf,Warrior/Ranger,Blue Mountain Dwarf-hold,1,3,0,3,8,-1,Angelo Montanini,6,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.|
Ori,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,2,7,0,Angelo Montanini,6,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Orophin,Character,CB,Elf,Warrior/Ranger,Lorien,0,2,0,2,7,0,Lori Deitrick,6,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Pallando,Character,F2,Wizard,Warrior/Ranger/Sage/Diplomat,Grey Havens,0,0,10,6,9,0,Angus McBride,6,|Unique.  His controlling player may keep one more card than normal in his hand.  Opponent must discard his cards face-up.|
Peath,Character,F1,Man,Ranger/Diplomat,Dunnish Clan-hold,1,4,1,4,7,0,Stefano Baldo,5,|Unique.  +4 direct influence against the Dunlending faction. Against Nazgul, +5 to her prowess, his body is halved (round up).|
Pippin,Character,U,Hobbit,Scout,Bag End,1,4,1,1,9,0,Angelo Montanini,5,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +2.|
Radagast,Character,F2,Wizard,Warrior/Scout/Ranger/Diplomat,Rhosgobel,0,0,10,6,9,1,Angelo Montanini,5,|Unique.  If his company moves to a new site during the movement/hazard phase, he may draw 1 additional card for each Wilderness [w] region in his company''s site path.  +1 to all corruption checks.|
Robin Smallburrow,Character,F2,Hobbit,Scout,Bag End,1,3,0,1,9,0,Angelo Montanini,5,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +2.|
Sam Gamgee,Character,U,Hobbit,Scout/Ranger,Bag End,1,4,0,1,9,3,Angelo Montanini,4,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +3.|
Saruman,Character,F2,Wizard,Scout/Ranger/Sage/Diplomat,Isengard,0,0,10,6,9,0,Angus McBride,4,|Unique.  May tap to use a Palantir.  At the beginning of each of his end-of-turn phases, he may tap to take one "spell" card from his discard pile and return it to his hand.|
Theoden,Character,F1,Man,Warrior/Diplomat,Edoras,2,6,3,5,6,0,Angus McBride,4,|Unique.  +2 direct influence against the Riders of Rohan faction.|
Thorin II,Character,R,Dwarf,Warrior/Scout/Diplomat,Blue Mountain Dwarf-hold,3,8,2,5,8,0,Angelo Montanini,3,|Unique.  +2 direct influence against Blue Mountain Dwarves. +3 prowess against Orcs.  +2 direct influence against Dwarves and Dwarf factions.|
Thranduil,Character,F1,Elf,Warrior/Ranger/Sage,Thranduil''s Halls,3,9,3,7,8,0,Rob Alexander,3,|Unique.  +2 direct influence against the Wood-elves faction.|
Voteli,Character,CB,Man,Ranger/Sage,Lossadan Camp,1,3,1,3,6,0,Stefano Baldo,2,|Unique.  +2 direct influence against the Lossoth faction. Against Nazgul, +5 to her prowess, and his body is halved (round up).|
Vygavril,Character,R,Man,Diplomat/Sage,Southron Oasis,1,3,1,2,7,0,Jo Hartwig,7,|Unique.  +2 direct influence against the Southron faction. Against Nazgul, +6 to prowess, and his body is halved (round up).|
Wacho,Character,U,Man,Scout/Sage,Woodmen-town,0,2,0,1,8,0,Stefano Baldo,7,|Unique.  +2 direct influence against the Woodmen faction.|'.! !

!MEGElementFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 16:40'!
spoilerString

	^self subclassResponsibility.! !

MEGElementFactory subclass: #MEGResourcesFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGResourcesFactory methodsFor: 'private' stamp: 'SergioFedi 6/21/2016 12:06'!
defineRecruitmentForFaction: aMEGResource

	| checkValueIndex stringBeginningWithCheckValue checkValue |
	checkValueIndex := (aMEGResource description indexOfSubCollection: 'greater than ') + 13.
	(checkValueIndex = 13) 
		ifTrue:  [ 
			checkValue := 0.
		]
		ifFalse: [
			stringBeginningWithCheckValue := aMEGResource description 
				copyFrom: checkValueIndex
				to: aMEGResource description size.
			checkValue := (stringBeginningWithCheckValue substrings: '. ') first asNumber].
	aMEGResource recruitment: (Dictionary with: 'checkValue' -> checkValue).! !

!MEGResourcesFactory methodsFor: 'private' stamp: 'SergioFedi 6/21/2016 11:43'!
isFaction: resource

	^ resource resourceClass endsWith: 'faction'.
	
! !

!MEGResourcesFactory methodsFor: 'public' stamp: 'SergioFedi 6/21/2016 12:12'!
newFactions
	^ (self resourcesFromParts: self processedSpoilerString) select: [:resource |
		self isFaction: resource].! !

!MEGResourcesFactory methodsFor: 'private' stamp: 'SergioFedi 6/21/2016 11:12'!
partsOf: aString between: aCharacter

	self assert: (aString occurrencesOf: aCharacter) even.
	^aString substrings: aCharacter asString.
! !

!MEGResourcesFactory methodsFor: 'private' stamp: 'SergioFedi 6/21/2016 11:11'!
processedSpoilerString

	^self partsOf: self spoilerString between: $|.! !

!MEGResourcesFactory methodsFor: 'private' stamp: 'FedericoFigueredo 6/23/2016 08:51'!
resourceFromStats: stats description: description
	| resource fields |
	"1- NAME
	 2- TYPE
	 3- RARITY
	 4- CLASS
	 5- MP
	 6- MIND
	 7- INFLUENCE
	 8- PROWESS
	 9- BODY
	10- CORRUPT
	11- ALT_MP
	12- ALT_INFL
	13- ALT_PROW
	14- ALT_BODY
	15- ALT_CORRPT
	16- ARTIST
	17- RANDOM#
	18- |DESCRIPTION|"
	fields := stats substrings: #($,).
	resource := MEGResource new.
	resource name: fields first trimBoth.
	resource resourceClass: (fields at: 4).
	resource marshallingPoints: (fields at: 5) asNumber.
	resource description: (description copyReplaceAll: Character cr asString with: Character space asString).
	(self isFaction: resource)
		ifTrue: [ self defineRecruitmentForFaction: resource ].
	^ resource! !

!MEGResourcesFactory methodsFor: 'private' stamp: 'SergioFedi 6/21/2016 12:11'!
resourcesFromParts: aCollection

	^aCollection pairsCollect: [ :stats :description | self resourceFromStats: stats description: description ].! !

!MEGResourcesFactory methodsFor: 'private' stamp: 'SergioFedi 6/21/2016 10:49'!
spoilerString

	^'A Chance Meeting,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,Randy Gallegos,5,|A character (even a Hobbit) may
be brought into play with direct
influence at any Free-hold [F],
Border-hold [B], or Ruins &
Lairs [R].|
A Friend or Three,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Quinton Hoover,5,|For every character in the
influencing character''s company,
A Friend or Three gives a +1
modification to an influence
check or to a corruption check
made by a character in the same
company.|
Align Palantir,Resource,U,Permanent-event,2,0,0,0,0,2,0,0,0,0,0,Eric David Anderson,4,|Sage only if a Palantir is in
his company.  Keep with the
Palantir; bearer now has the
ability to use the Palantir.
Discard Align Palantir if the
company carrying the Palantir
moves.|
Anduin River,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Mark Poole,8,|Playable at the end of the
organization phase on a company
containing a ranger.  If the
company uses region cards for
its site path, tap the ranger to
move as if the following pairs
of regions were adjacent: Rohan
and Dagorlad, Anorien and
Dagorlad, Anorien and Ithilien,
Lebennin and Ithilien, Lebennin
and Harondor.  Otherwise, if the
site moved to is in one of the
regions listed above, the hazard
limit is reduced by two (to a
minimum of two).  Cannot be
duplicated on a given company.|
Anduril,Resource,R,Permanent-event,1,0,0,0,0,1,4,1,4,0,0,N. Taylor Blanchard,7,|Unique.  Sage only during the
site phase at an untapped site
where "information" is playable.
Tape the sage and the site.
Sage makes a corruption check
modified by -3.  Keep sage
tapped until Anduril is stored
at a Haven [H].  Once stored,
you may discard a stored
Reforging and place Anduril with
Narsil.  In addition to Narsil''s
effects, Anduril gives its
bearer 4 marshalling points, +4
prowess (to a maximum of 11), +1
direct influence, and one more
corruption point.  Anduril may
be tapped to untap a Dunadan
character in the same company,
but its bearer must make a
corruption check modified by -1.|
Army of the Dead,Resource,R,Special faction,6,0,0,0,0,0,0,0,0,0,0,Lubov,8,|Unique.  Playable at Vale of
Erech.  May only be played by
Aragorn II on the same turn that
he plays Paths of the Dead.|
Ash Mountains,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,8,|Playable at the end of the
organization phase on a company
containing a ranger.  If the
company uses region cards for
its site path, tap the ranger to
move as if the following pairs
of regions were adjacent:
Dagorlad and Gorgoroth, Horse
Plains and Gorgoroth.  The
company faces an attack at the
beginning of its movement/hazard
phase:  Orcs - 4 strikes with 8
prowess.  Otherwise, if the site
moved to is in one of the
regions listed above, the hazard
limit is reduced by 2 (to a
minimum of 2).  Cannot be
duplicated on a given company.|
Athelas,Resource,U,Minor item,0,0,0,0,0,1,0,0,0,0,0,Angelo Montanini,7,|A Dunadan can tap and use this
item to heal a character in his
company (change from wounded to
well, character remains tapped).
Aragorn II can also tap and use
this item to remove a corruption
card from a character in his
company.  Discard after use.|
Beautiful Gold Ring,Resource,CA2,Gold ring item,1,0,0,0,0,1,0,0,0,0,0,Larry Forcella,7,|Discard Beatiful Gold Ring when
tested.  If tested, make a roll
(or draw a #) to determine which
ring card may be immediately
played:
        - The One Ring (12+);
        - a Dwarven Ring (10,
11, 12+);
        - a Magic Ring (1, 2, 3,
4, 5, 6, 7);
        - a Lesser Ring (any
result).|
Beornings,Resource,F1,Man faction,2,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,8,|Unique.  Playable at Beorn''s
House if the influence check is
greater than 7.  Standard
modifications: Men (+1).|
Bill the Pony,Resource,U,Ally,1,1,0,-2,6,0,0,0,0,0,0,Gail McIntosh,12,|Unique.  Playable at Bree of Bag
End; playable even if the site
is tapped.  If at a non-Haven
site and if his company''s size
is three of less, you may
discard Bill the Pony at the end
of his company''s turn and
replace its site with the
nearest Haven [H].|
Black Arrow,Resource,P_INQ10,Minor item,0,0,0,0,0,1,0,0,0,0,0,Ron Chironna,7,|Warrior only.  Tap Black Arrow
to give -1 to the prowess and
body of any one attack against
bearer''s company.  When Black
Arrow is tapped, discard it if
its bearer is not a Man.|
Block,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,4,|Warrior only.  Warrior does not
tap agains one strike (unless he
is wounded by the strike).|
Blue Mountain Dwarves,Resource,U,Dwarf faction,3,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,8,|Unique.  Playable at Blue
Mountain Dwarf-hold if the
influence check is greater than
9.  Standard modifications:
Elves (-2), Dwarves (+2).|
Book of Mazarbul,Resource,U,Special item,1,0,0,0,0,2,5,0,0,0,0,N. Taylor Blanchard,7,|Unique.  Only playable at Moria.
May be stored at a Dwarf-hold
for 5 marshalling points.  If
its bearer is a sage, tap the
bearer during your organization
phase to increase your hand size
by 1 until your next untap
phase.|
Bridge,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Stefano Baldo,8,|Playable at the end of the
movement/hazard phase on a
company that moved to a Haven
[H].  That company may move to
an additional site on the same
turn.  Another site card may be
played and a movement/hazard
phase immediately follows for
that company.|
Clear Skies,Resource,R,Long-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,10,|Environment.  Playable only if
Gates of Morning is in play.
The prowess of each character is
modified by +2.|
Concealment,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Quinton Hoover,3,|Scout only.  Tap scout to cancel
one attack against his company.|
Cracks of Doom,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,3,|Only playable if The One Ring is
at Mount Doom.  Its bearer must
make a corruption check modified
by -4.  If successful, The One
Ring is destroyed and its
bearer''s player wins.
Otherwise, discard The One Ring
and its bearer.|
Dagger of Westernesse,Resource,CA2,Minor item,0,0,0,1,0,1,0,0,0,0,0,Stefano Baldo,6,|Weapon.  +1 to prowess to a
maximum of 8.|
Dark Quarrels,Resource,CA2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Randy Gallegos,2,|Cancel one attack by Orcs,
Trolls, or Men.  Alternatively,
if Gates of Morning is in play,
the number of strikes from any
attack is reduced to half of its
original number, rounded up.|
Dodge,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Ron Rousselle II,12,|Target character does not tap
agains one strike (unless he is
wounded by the strike).  If
wounded by the strike, his body
check is modified by -1.|
Dreams of Lore,Resource,CA2,Permanent-event,2,0,0,0,0,0,0,0,0,0,0,Kevin Ward,11,|Sage only during the site phase
at an untapped site where
"Information" is playable.  Tap
the sage and the site.  Sage may
not untap until Dreams of Lore
is stored at a Haven [H] during
his organization phase.  May not
be transferred.|
Dunlendings,Resource,F1,Man faction,2,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,8,|Unique.  Playable at Dunnish
Clan-hold if the influence check
is greater than 9.  Standard
Modifications:  Men (-1),
Dunedain )-1), Dwarves (-1).|
Durin''s Axe,Resource,U,Major item,2,0,0,2,0,2,4,0,4,0,3,Ron Rousselle II,6,|Unique.  Weapon.  +2 prowess (+4
if held by a Dwarf) to a maximum
of 9.  If held by a Dwarf, 4
marshalling points and 3
corruption points.|
Dw. Ring of Barin''s Tribe,Resource,R,Special item,4,0,2,2,1,3,6,7,4,0,5,Storn Cook,7,|Unique.  Dwarven Ring.  Playable
only with a Gold Ring and after
a test indicates a Dwarven Ring.
Values in parentheses and
brackets apply to a Dwarf
bearer.  Tap a Dwarf bearer to
search your play deck for a
major item playable at the
bearer''s site.  Play this item
immediately or discard;
reshuffle the play deck.  Bearer
makes a corruption check
modified by +2.|
Dw. Ring of Bavor''s Tribe,Resource,R,Special item,4,0,2,2,1,3,6,7,4,0,5,Dan Frazier,7,|Unique.  Dwarven Ring.  Playable
only with a Gold Ring and after
a test indicates a Dwarven Ring.
Values in parentheses and
brackets apply to a Dwarf
bearer.  Tap a Dwarf bearer to
search your play deck for a
greater item playable at the
bearer''s site.  Play this item
immediately or discard;
reshuffle the play deck.  Bearer
makes a corruption check
modified by +2.|
Dw. Ring of Druin''s Tribe,Resource,R,Special item,4,0,2,2,1,3,6,7,4,0,5,Daniel Gelon,6,|Unique.  Dwarven Ring.  Playable
only with a Gold Ring and after
a test indicates a Dwarven Ring.
Values in parentheses and
brackets apply to a Dwarf
bearer.  Tap a Dwarf bearer to
search your play deck for a
greater item playable at the
bearer''s site.  Play this item
immediately or discard;
reshuffle the play deck.  Bearer
makes a corruption check
modified by +2.|
Dw. Ring of Durin''s Tribe,Resource,R,Special item,4,0,2,2,1,3,6,7,4,0,5,Dan Frazier,6,|Unique.  Dwarven Ring.  Playable
only with a Gold Ring and after
a test indicates a Dwarven Ring.
Values in parentheses and
brackets apply to a Dwarf
bearer.  Tap a Dwarf bearer to
untap the site he is currently
at.  Bearer makes a corruption
check modified by +2.|
Dw. Ring of Dwalin''s Tribe,Resource,R,Special item,4,0,2,2,1,3,6,7,4,0,5,Daniel Gelon,6,|Unique.  Dwarven Ring.  Only
playable with a Gold Ring and
after a test indicates a Dwarven
Ring.  Values in parentheses and
brackets apply to a Dwarf
bearer.  Tap a Dwarf bearer to
search through your play deck
for a major item playable at the
bearer''s site.  Play this item
immediately or discard;
reshuffle the play deck.  Bearer
makes a corruption check
modified by +2.|
Dw. Ring of Thelor''s Tribe,Resource,U,Special item,4,0,2,2,1,3,6,7,4,0,5,Melissa Benson,6,|Unique.  Dwarven Ring.  Playable
only with a Gold Ring and after
a test indicates a Dwarven Ring.
Values in parentheses apply to a
Dwarf bearer.  Tap a Dwarf
bearer to search your play deck
and/or discard pile for any one
or two minor items; place these
items in your hand and reshuffle
your play deck.  Bearer makes a
corruption check modified by +2.|
Dw. Ring of Thrar''s Tribe,Resource,U,Special item,4,0,2,2,1,3,6,7,4,0,5,Audrey Corman,6,|Unique.  Dwarven Ring.  Playable
only with a Gold Ring and after
a test indicates a Dwarven Ring.
Values in parentheses apply to a
Dwarf bearer.  Tap a Dwarf
bearer to search your play deck
and/or discard pile for any one
or two minor items; place these
items in your hand and reshuffle
your play deck.  Bearer makes a
corruption check modified by +2.|
Eagle-mounts,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Ron Rouselle II,7,|Playable only at the end of the
organization phase on a company
with a diplomat that begins the
turn at Eagles'' Eyrie.  Company
may move to any site that is not
a Shadow-hold [S] or a Dark-hold
[D].  Opponent may only play
hazard creatures that are keyed
to the company''s site.|
Earth of Galadriel''s Orchard,Resource,U,Special item,0,0,0,0,0,1,2,0,0,0,0,Edward Beard, Jr.,6,|Unique.  Only playable at
Lorien.  2 marshalling points if
stored at Bag End.|
Easterlings,Resource,R,Man faction,4,0,0,0,0,0,0,0,0,0,0,Heather Hudson,7,|Unique.  Playable at Easterling
Camp if the influence check is
greater than 9.  Standard
modifications: Dunedain (-2).|
Elf-song,Resource,R,Long-event,0,0,0,0,0,0,0,0,0,0,0,Stefano Baldo,10,|When Elf-song comes into play,
each character at a Haven may
immediately remove one
corruption card.  While Elf-song
is in play, no character at a
Haven may be discarded or
returned to its owner''s hand for
any reason.|
Elf-stone,Resource,CB2,Minor item,0,0,0,0,0,1,0,2,0,0,0,Mark Poole,6,|+2 to direct influence used
agains an Elf character or an
Elf faction.  May not be
duplicated on a given character.|
Elven Cloak,Resource,CA2,Minor item,0,0,0,0,0,1,0,0,0,0,0,Rob Alexander,6,|Tap Elven Cloak to cancel one
strike against bearer; the
strike must be keyed to
Wilderness [w].  May not be
duplicated on a given character.|
Elves of Lindon,Resource,R,Elf faction,2,0,0,0,0,0,0,0,0,0,0,Liz Danforth,7,|Unique.  Playable at Grey Havens
if the influence check is
greater than 9.  Standard
Modifications: Dunedain (+1),
Elves (+2).|
Ent-draughts,Resource,U,Special item,0,0,0,1,0,0,0,0,0,0,0,Randy Gallegos,5,|Only playable at Wellinghall as
a minor item (even if
Wellinghall is already tapped).
+1 to prowess.  This item may
not be stolen, transferred, or
stored.  May not be duplicated
on a given character.|
Ents of Fangorn,Resource,F1,Ent faction,3,0,0,0,0,0,0,0,0,0,0,Lori Deitrick,7,|Unique.  Playable at Wellinghall
if the influence check is
greater than 9.  Standard
Modifications: Hobbits (+4).|
Escape,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Eric David Anderson,10,|Cancels an attack against a
company.  One character of your
choice in the company is wounded
(no body check is required).|
Fair Gold Ring,Resource,CA2,Gold ring item,1,0,0,0,0,1,0,0,0,0,0,N. Taylor Blanchard,5,|Discard Fair Gold Ring when
tested.  If tested, make a roll
(or draw a #) to determine which
ring card may be immediately
played:
        - The One Ring (11,
12+);
        - a Dwarven Ring (9, 10,
11, 12+);
        - a Magic Ring (1, 2, 3,
4, 5, 6);
        - a Lesser Ring (any
result).|
Fair Sailing,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Mark Poole,7,|Playable at the end of the
organization phase if target
company plays a new site card.
The hazard limit for the target
company decreases by one for
every Coastal Sea [c] in its
site path (to a minimum of two).
Cannot be duplicated on the same
company.|
Fair Travels in Border-lands,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Rob Alexander,8,|Playable at the end of the
organization phase if target
company plays a new site card.
The hazard limit for the target
company decreases by one for
every Border-land [b] in its
site path (to a minimum of two).
Cannot be duplicated on the same
company.|
Fair Travels in Dark-domains,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,8,|Playable at the end of the
organization phase if target
company plays a new site card.
If the site path has at least
one Dark-domain [d], the hazard
limit for the target company
decreases by one (or by two if
Gates of Morning is in play) to
a minimum of two.  Cannot be
duplicated on the same company.|
Fair Travels in Free-domains,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Mark Poole,8,|Playable at the end of the
organization phase if target
company plays a new site card.
The hazard limit for the target
company decreases by one for
every Free-domain [f] in its
site path (to a minimum of two).
Cannot be duplicated on the same
company.|
Fair Travels in Shadow-lands,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Mark Poole,8,|Playable at the end of the
organization phase if target
company plays a new site card.
If the site path has at least
one Shadow-land [s], the hazard
limit for the target company
decreases by one (or by two if
Gates of Morning is in play) to
a minimum of two.  Cannot be
duplicated on the same company.|
Fair Travels in Wilderness,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Mark Poole,8,|Playable at the end of the
organization phase if target
company plays a new site card.
The hazard limit for the target
company decreases by one for
every Wilderness [w] in its site
path (to a minimum of two).
Cannot be duplicated on the same
company.|
Far-sight,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,11,|Sage only during the site phase
at an untapped site where
"Information" is playable.  Tap
the sage and the site to search
through your play deck and
choose an item that you must
reveal to your opponent.  This
item is placed in your hand and
the play deck is reshuffled.
The sage makes a corruption
check.|
Favor of the Valar,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,David Deitrick,9,|Unique.  Playable during your
organization phase.  Shuffle
your hand and your discard pile
into you play deck (site cards
remain in the discard pile).
Draw a new hand of 8 cards.
Remove Favor of the Valar from
the game.|
Fellowship,Resource,CA2,Permanent-event,0,0,0,1,0,1,0,0,0,0,0,Angus McBride,10,|Only playable at a Haven [H]
during the organization phase on
a company that has four or more
characters and allies.  +1 to
prowess and +1 to corruption
checks for all characters and
allies inthe company.  Discard
this card if a character of ally
joins or leaves the company for
any reason.|
Fog,Resource,U,Long-event,0,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,9,|Environment.  Playable only if
Gates of Morning is in play.
Treat all Free-domains [f] as
Border-lands [b] and all
Border-lands [b] as Wildernesses
[w] and all Shadow-lands [s] as
Wildernesses [w] and all
Dark-domains [d] as Shadow-lands
[s].  Cannot be duplicated.|
Ford,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Dameon Willich,7,|Playable only at the end of the
organization phase.  Tap a
ranger to prevent opponent from
playing hazard creatures keyed
to Wilderness [w] against the
ranger''s company.|
Gates of Morning,Resource,F5,Permanent-event,0,0,0,0,0,0,0,0,0,0,0,Melissa Benson,9,|Environment.  All environment
hazard cards in play are
immediately discarded, and all
hazard environment effects are
canceled.  Cannot be duplicated.|
Glamdring,Resource,U,Major item,2,0,0,3,0,1,0,0,0,0,0,Audrey Corman,5,|Unique.  Weapon.  +3 to prowess
to a maximum of 8 (a maximum of
9 against Orcs).|
Goldberry,Resource,U,Ally,1,2,0,0,0,0,0,0,0,0,0,Angus McBride,11,|Unique.  Playable at Old Forest.
May not be attacked.  Tap
Goldberry to cancel any effect
that would cause her company to
return to its site of origin
after declaring its movement to
a new site.  Alternatively, tap
Goldberry to cancel one attack
against her company keyed to
Wilderness [w].|
Gollum,Resource,U,Scout ally,2,4,0,2,9,0,0,0,0,0,0,Angus McBride,11,|Unique.  Playable at Goblin-gate
or Moria.  If his company''s size
is less than three, tap Gollum
to cancel one attack against his
company keyed to Wilderness [w]
or Shadow-land [s].  Tap Gollum
if he is at the same non-Haven
site as The One Ring; then both
Gollum and The One Ring are
discarded.|
Gollum''s Fate,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Randy Gallegos,9,|Unique.  Only playable if The
One Ring and Gollum are both at
Mount Doom diring the site
phase.  The One Ring is
destroyed and its bearer''s
player wins.|
Great Ship,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Audrey Corman,5,|If company''s current site path
contains a coastal sea region,
until the end of the turn and
character in the company may tap
to cancel the effects of one
hazard that targets the company.|
Great-road,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Pat Morrissey,7,|Playable only at the end of the
organization phase on a company
that starts at a Haven [H].
Opponent draws twice the normal
number of cards for this company
during the movement/hazard
phase.  At the end of the turn,
the company may replace its site
card with the Haven card at
which it began the turn.|
Great-shield of Rohan,Resource,U,Major item,2,0,0,0,2,2,0,0,0,0,0,Audrey Corman,5,|Unique.  Shield.  +2 to body to
a maximum of 9.  Warrior only:
tap Great Shield of Rohan to
remain untapped against one
strike (unless bearer is wounded
by the strike).|
Gwaihir,Resource,R,Ally,2,4,0,4,8,0,0,0,0,0,0,Gail McIntosh,10,|Unique.  Playable at Eagles''
Eyrie.  If his company''s size is
two or less, you may discard
Gwaihir during the movement
phase to allow his company to
move to any site that isnot in a
Shadow-land [s] or Dark-domain
[d]; only hazard creatures keyed
to the site may be played on a
company that moves in this
fashion.|
Halfling Stealth,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Quinton Hoover,9,|Hobbit only.  Cancel one strike
against the Hobbit.|
Halfling Strength,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,9,|Hobbit only.  The Hobbit may
untap or he may move from
wounded status to well and
untapped during his organization
phase or he may receive a +4
modification to one corruption
check.|
Hauberk of Bright Mail,Resource,CA,Major item,2,0,0,0,2,1,0,0,0,0,0,Audrey Corman,4,|Armor.  Warrior only: +2 to body
to a maximum of 9.|
Healing Herbs,Resource,CA2,Minor item,0,0,0,0,0,1,0,0,0,0,0,Quinton Hoover,4,|The bearer can tap and discard
this item to heal a character in
his company, changing the
character''s status from wounded
to well and untapped.
Alternatively, the bearer can
tap and discard this item to
untap a character that is not
wounded.|
Hiding,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Quinton Hoover,9,|Scout only at the end of the
organization phase.  Scout''s
company may not move to another
site this turn.  Cancels all
hazard creature attacks against
the scout''s company this turn.|
Hillmen,Resource,U,Man faction,1,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,7,|Unique.  Playable at Cameth Brin
if the influence check is
greater than 9.  Standard
Modifications: Men (+1).|
Hobbits,Resource,R,Hobbit faction,1,0,0,0,0,0,0,0,0,0,0,Quinton Hoover,7,|Unique.  Playable at Bag End if
the influence check is greater
than 8.  Standard Modifications:
Hobbits (+4).|
Horn of Anor,Resource,CB,Minor item,0,0,0,0,0,1,0,2,0,0,0,Angelo Montanini,4,|+2 to direct influence used
against a faction.  May not be
duplicated on a given character.|
Horses,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Margaret Organ-Kean,7,|Hazard limit for a company is
decreased by two (to a minimum
of 2).  The prowess of any
hazard creatures played against
this company is modified by +2.|
Iron Hill Dwarves,Resource,F1,Dwarf faction,4,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,6,|Unique.  Playable at Iron Hill
Dwarf-hold if the influence
check is greater than 8.
Standard Modifications: Elves
(-2), Dwarves (+2).|
Kindling of the Spirit,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Edward Beard, Jr.,8,|Spell.  Wizard only.  +2 prowess
against one attack for all
characters in the same company
as the Wizard.  Wizard makes a
corruption check modified by -2.|
Knights of Dol Amroth,Resource,U,Dunadan faction,3,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,6,|Unique.  Playable at Dol Amroth
if the influence check is
greater than 8.  Standard
Modifications: Dunedain (+1).|
Lapse of Will,Resource,U,Long-event,0,0,0,0,0,0,0,0,0,0,0,David Deitrick,8,|The prowess of each attack is
modified by -1.  The prowess of
each Nazgul attack is modified
by -3.|
Leaflock,Resource,U,Ally,2,3,0,5,8,0,0,0,0,0,0,Gail McIntosh,10,|Unique.  Playable at
Wellinghall.  Tap to cancel the
effects of one hazard that
targets his company.  May not be
attacked by automatic-attacks or
hazards keyed to his site.
Discard Leaflock if his company
moves to a site that is not in:
Fangorn, Rohan, Gap of Isen,
Wold & Foothills, Enedhwaith,
Old Pukel-land, Brown Lands,
Anduin Vales, or Redhorn Gap.|
Lesser Ring,Resource,U,Special item,2,0,2,0,0,1,0,0,0,0,0,Larry Forcella,3,|Lesser Ring.  Playable only with
a Gold Ring and after a test
indicates Lesser Ring.  +2 to
direct influence.|
Lordly Presence,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,8,|Diplomat only.  +5 to an
influence check against a
faction.  If the influence check
is successful, draw a card.|
Lossoth,Resource,U,Man faction,2,0,0,0,0,0,0,0,0,0,0,April Lee,6,|Unique.  Playable at Lossadan
Camp if the influence check is
greater than 8.  Standard
Modifications: Men (+1).|
Lucky Search,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Ron Rousselle II,8,|Scout only.  During the site
phase, tap a scout at a
Shadow-hold [S] or Dark-hold
[D].  Turn over cards from your
play deck one at a time until
you reveal a non-special item or
reach the end.  If you reveal a
non-special item, the scout
takes control of it.  In any
case, the scout must face a
single strike attack with a
prowess equal to 3 plus the
number of cards revealed; this
attack/strike cannot be
cancelled.  Discard all revealed
cards except the item.|
Lucky Strike,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,8,|Warrior only.  Make two rolls
(or draw two #''s) against a
strike and shoose one of the two
results to use.|
Magic Ring of Courage,Resource,U,Special item,3,0,0,0,0,2,0,0,2,0,0,Edward Beard, Jr.,3,|Magic Ring.  Playable only with
a Gold Ring and after a test
indicates a Magic Ring.  Gives
the bearer warrior skill.  If
the bearer is already a warrior,
he gets +2 to prowess.  May not
be duplicated on a given
character.|
Magic Ring of Lore,Resource,U,Special item,3,0,0,0,0,2,0,0,0,0,0,Audrey Corman,3,|Magic Ring.  Playable only with
a Gold Ring and after a test
indicates a Magic Ring.  Gives
the bearer sage skill.  If the
bearer is already a sage, he may
tap to use a Palantir.  May not
be duplicated on a given
character.|
Magic Ring of Nature,Resource,U,Special item,3,0,0,0,0,2,0,0,0,0,0,Quinton Hoover,12,|Magic Ring.  Playable only with
a Gold Ring and after a test
indicates a Magic Ring.  Gives
the bearer ranger skill.  If the
bearer is already a ranger, he
may tap to cancel an attack
against his company.  May not be
duplicated on a given character.|
Magic Ring of Stealth,Resource,U,Special item,3,0,0,0,0,2,0,0,0,0,0,Melissa Benson,11,|Magic Ring.  Playable only with
a Gold Ring and after a test
indicates a Magic Ring.  Gives
the bearer scout skill.  If the
bearer is already a scout, he
may tap the Magic Ring of
Stealth to cancel a strike
directed against him.  May not
be duplicated on a given
character.|
Magic Ring of Words,Resource,U,Special item,3,0,0,0,0,2,0,3,0,0,0,Ronald Chironna,11,|Magic Ring.  Playable only with
a Gold Ring and after a test
indicates a Magic Ring.  Gives
the bearer diplomat skill.  If
the bearer is already a
diplomat, he gets +3 to direct
influence.  May not be
duplicated on a given character.|
Men of Anfalas,Resource,U,Man faction,2,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,6,|Unique.  Playable at Lond Galen
if the influence check is
greater than 8.  Standard
Modifications: Dunedain (+1).|
Men of Anorien,Resource,F1,Man faction,2,0,0,0,0,0,0,0,0,0,0,David Deitrick,6,|Unique.  Playable at Minas
Tirith if the influence check is
greater than 7.  Standard
Modifications: Dunedain (+1).|
Men of Dorwinion,Resource,U,Man faction,3,0,0,0,0,0,0,0,0,0,0,Lori Deitrick,5,|Unique.  Playable at Shrel-Kain
if the influence check is
greater than 6.  Standard
Modifications: Men (+1).|
Men of Lamedon,Resource,U,Man faction,2,0,0,0,0,0,0,0,0,0,0,David Deitrick,5,|Unique.  Playable at Vale of
Erech if the influence check is
greater than 7.  Standard
Modifications: Dunedain (+1).|
Men of Lebennin,Resource,U,Man faction,2,0,0,0,0,0,0,0,0,0,0,Lori Deitrick,5,|Unique.  Playable at Pelargir if
the influence check is greater
than 7.  Standard Modifications:
Dunedain (+1).|
Men of Northern Rhovanion,Resource,U,Man faction,2,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,5,|Unique.  Playable at Lake-town
if the influence check is
greater than 6.  Standard
Modifications: Men (+1).|
Mirror of Galadriel,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,7,|Only playable at Lorien.  You
may look at your opponent''s hand
and choose to look at either the
top five cards of his play deck
or your play deck.  Shuffle
those 5 cards and return them to
the top of their play deck.|
Miruvor,Resource,CA,Minor item,0,0,0,0,0,1,0,0,0,2,0,Darryl Elliott,10,|Discard to give +2 body (to a
maximum of 10) for all
characters in bearer''s company
until the end of the turn.|
Misty Mountains,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Rob Alexander,7,|Playable at the end of the
organization phase on a company
containing a ranger.  If the
company uses region cards for
its site path, tap the ranger to
move as if the following pairs
of regions were adjacent:
Rhudaur and Anduin Vales,
Rhudaur and Wold & Foothills,
Hollin and Wold & Foothills,
Hollin and Fangorn, Dunland and
Fangorn.  Otherwise, if the site
moved to is in one of the
regions listed above, the hazard
limit is reduced by two (to a
minimum of two).  Cannot be
duplicated on a given company.|
Moon,Resource,U,Long-event,0,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,9,|Environment.  If Gates of
Morning is in play, treat all
Wildernesses [w] as Border-lands
[b] and all Border-lands [b] as
Free-domains [f] for the
purposes of playing hazards.  If
Doors of Night is in play, treat
all Dark-domains [d] as
Shadow-lands [s] and all
Shadow-lands [s] as Wildernesses
[w] for the purposes of playing
hazards.  Cannot be duplicated.|
Morannon,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,David Martin,6,|Playable at the end of the
organization phase on a company
that has a size of less than
three, contains a scout, and
begins the turn at a site in
Dagorlad.  This card is used as
a Dark-hold [D] site card in
Udun that is moved to using the
following site-path:
Shadow-lands [s], Dark-lands [d]
(the moving player draws 2 cards
and his opponent draws 5 cards).
The company can later leave this
site using region cards or by
using the following site path to
Lorien: 2x Dark-lands [d],
Shadow-lands [s], 2x Wilderness
[w], Free-lands [f],
Border-lands [b].  Discard
Morannon when the company
successfully plays a new site
card.|
Mountains of Shadow,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,Rob Alexander,6,|Playable at the end of the
organization phase on a company
containing a ranger.  If the
company uses region cards for
its site path, tap the ranger to
move as if the following pairs
of regions were adjacent:
Ithilien and Gorgoroth, Ithilien
and Nurn, Harondor and Nurn.
The company faces an attack at
the beginning of its
movement/hazard phase: Orcs - 4
strikes with 9 prowess.
Otherwise, if the site moved to
is in one of the regions listed
above, the hazard limit is
reduced by 2 (to a minimum of
2).  Cannot be duplicated on a
given company.|
Muster,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,David Deitrick,7,|Warrior only.  An influence
check against a faction is
automatically successful; no
roll (or draw) is necessary.|
Narsil,Resource,U,Greater item,3,0,1,1,0,2,0,0,0,0,0,Audrey Corman,10,|Unique.  Weapon.  +1 to prowess
and direct influence.|
Narya,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Jeffrey Reitz,7,|Gandalf only.  +4 prowess, +1
body, +2 direct influence for
the rest of the turn.
Immediately untap all unwounded
characters in Gandalf''s company.
Gandalf makes a corruption check
modified by -5.|
Nenya,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,7,|Galadriel only.  +2 prowess, +2
body, +2 direct influence for
the rest of the turn.  Galadriel
makes a corruption check
modified by -3, by -1 if in a
Haven [H].  Any one corruption
check made by a character not in
a Shadow-hold [S] or Dark-hold
[D] is automatically successful.|
New Friendship,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,7,|Diplomat only.  +3 to any one
influence check or +2 to a
corruption check made by a
character in the same company.|
Old Friendship,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,7,|Diplomat only.  +5 to an
influence check against a
character or +4 to a corruption
check made by a character in the
same company.|
Old Road,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,6,|Allows a character at a Haven
[H] to attempt to bring a
faction into play.  The length
of the site path from this Haven
to the site at which the faction
can be played must be two or
less (this must be verified by
an available site card).  The
influence check for this attempt
is modified by -1 and is not
modified by the influencing
character''s direct influence.|
Orcrist,Resource,U,Greater item,4,0,0,3,0,2,0,0,0,0,0,Audrey Corman,9,|Unique.  Weapon.  +3 to prowess
to a maximum of 9 (+4 prowess to
a maximum of 10 against Orcs).|
Palantir of Amon Sul,Resource,R,Greater item,3,0,0,0,0,3,5,0,0,0,0,Taylor Blanchard,9,|Unique.  Palantir.  If the
bearer''s company is ever below 2
characters and the company
moves, discard the Palantir.  5
marshalling points if stored in
a Haven [H].  With its bearer
able to use a Palantir, tap
Palantir of Amon Sul to look at
your opponent''s hand or tap it
to use the abilities of either
the Palantir of Annuminas or the
Palantir of Elostirion if either
one is in play.  Bearer makes a
corruption check.|
Palantir of Annuminas,Resource,R,Greater item,3,0,0,0,0,2,0,0,0,0,0,Margaret Organ-Keane,9,|Unique.  Palantir.  With its
bearer able to use a Palantir,
tap Palantir of Annuminas to
search through your play deck
and discard pile for a "sage
only" card.  Put this card in
your hand.  Reshuffle your play
deck.  Bearer makes a corruption
check.|
Palantir of Elostirion,Resource,U,Special item,2,0,0,0,0,2,0,0,0,0,0,Stefano Baldo,8,|Unique.  Palantir.  Playable
only at The White Towers.
Discard if the bearer moves.  If
the bearer is a sage, he may tap
Palantir of Elostirion to remove
one corruption card from an Elf
or a Wizard under your control.
Bearer makes a corruption check.|
Palantir of Minas Tirith,Resource,U,Special item,2,0,0,0,0,2,0,0,0,0,0,Jeffrey Reitz,8,|Unique.  Palantir.  Playable
only at Minas Tirith.  With its
bearer able to use a Palantir,
tap Palantir of Minas Tirith to
look at the top five cards of
your play deck; shuffle these 5
cards and return them to the top
of your play deck.  do the same
to your opponent''s play deck.
Bearer makes a corruption check.|
Palantir of Orthanc,Resource,U,Special item,2,0,0,0,0,2,0,0,0,0,0,Ronald Chironna,8,|Unique.  Palantir.  Playable
only at Isengard.  With its
bearer able to use a Palantir
and with at least 5 cards in
your play deck, tap Palantir of
Orthanc to choose one card from
your discard pile to place in
your play deck (reshuffle the
play deck).  Bearer makes a
corruption check.|
Palantir of Osgiliath,Resource,R,Greater item,3,0,0,0,0,3,5,0,0,0,0,Edward Beard, Jr.,8,|Unique.  Palantir.  If the
bearer''s company is ever below 4
character and the company moves,
discard.  5 marshalling pts. if
stored in a Haven [H].  With its
bearer able to use a Palantir,
tap Palantir of Osgiliath to
force the discard of any hazard
permanent-event or to duplicate
the effect of any Palantir in
play.  Bearer makes a corruption
check.|
Paths of the Dead,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Edward Beard, Jr.,6,|Playable only at the end of the
organization phase.  For its
movement, a company that starts
at the Dunharrow site and
contains Aragorn II may move to
the Vale of Erech site.  The
only hazard creatures that may
be played on this company are
Undead, but any Undead may be
played on the company.|
Persuasive Words,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,6,|Diplomat only.  Make two rolls
(or draw two #''s) when making an
influence check and choose one
result to use.|
Potion of Prowess,Resource,CA,Minor item,0,0,0,0,0,1,0,0,1,0,0,Darryl Elliott,7,|Discard to give +1 prowess to
all characters in bearer''s
company until the end of the
turn.|
Praise to Elbereth,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,6,|For each of your characters in
play that you choose to tap,
cancel one Nazgul event or one
Nazgul attack.  Additionally, if
Doors of Night is in play,
characters gain +1 prowess until
the end of the turn.|
Precious Gold Ring,Resource,CA2,Gold ring item,1,0,0,0,0,1,0,0,0,0,0,Jeffery Reitz,7,|Discard Precious Gold Ring when
tested.  If tested, make a roll
(or draw a #) to determine which
ring card may be immediately
played:
        - The One Ring (10, 11,
12+);
        - a Dwarven ring (8, 9,
10, 11, 12+);
        - a Magic Ring (1, 2, 3,
4, 5);
        - a Lesser Ring (any
result).|
Quickbeam,Resource,U,Ally,2,3,0,6,9,0,0,0,0,0,0,Gail McIntosh,10,|Unique.  Playable at
Wellinghall.  May not be
attacked by automatic-attacks or
hazards keyed to his site.|
Quiet Lands,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Douglas Chaffee,9,|Environment.  Until the end of
the turn, the number of strikes
for one automatic-attack at a
Shadow-hold [S] or Ruins & Lairs
[R] is reduced to half of its
original number (round up).
Alternatively, if Gates of
Morning is in play, treat one
Shadow-land [s] as a Wilderness
[w], or one Shadow-hold [S] as a
Ruins & Lairs [R] until the end
of the turn.  Cannot be
duplicated.|
Rangers of Ithilien,Resource,F1,Dunadan faction,3,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,4,|Unique.  Playable at Henneth
Annun if the influence check is
greater than 7.  Standard
Modifications: Dunedain (+1).|
Rangers of the North,Resource,F1,Dunadan faction,3,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,4,|Unique.  Playable at Bree if the
influence check is greater than
9.  Standard Modifications:
Dunedain (+1).|
Red Arrow,Resource,U,Major item,2,0,0,0,0,2,0,5,0,0,0,Darryl Elliott,7,|Unique.  Bearer may
automatically influence the
Riders of Rohan.  +5 to the
bearer''s direct influence
against any character with
Edoras as a home site.|
Red Book of Westmarch,Resource,U,Special item,0,0,0,0,0,1,1,2,0,0,0,Jeffery Reitz,7,|Unique.  Only playable at Bag
End.  +2 to direct influence
against a Hobbit character or
faction.  1 marshalling point if
stored at a Haven [H].|
Reforging,Resource,CA,Permanent-event,1,0,0,0,0,0,0,0,0,0,0,Ron Spencer,6,|Sage only during the site phase
at an untapped site where
"Information" is playable.  Tap
the sage and the site.  Sage may
not untap until Reforging is
stored at a Haven [H].  During
your organization phase, you may
tap a sage at a Haven and
discard a stored Reforging to
retrieve any minor or major
weapon, armor, or shield from
your discard pile.  The item
must be placed under the control
of a character in the sage''s
company.|
Rescue Prisoners,Resource,CA2,Permanent-event,3,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,6,|Playable at an already tapped
Dark-hold [D] or Shadow-hold [S]
during the site phase.  The
company faces a spider attack (2
strikes with 7 prowess).  If no
characters are untapped after
the attack, discard Rescue
Prisoners.  Otherwise, you may
tap 1 character in the company
and put Rescue Prisoners under
his control.  That character may
not untap until Rescue Prisoners
is stored at a Haven [H],
Border-hold [B], or Free-hold
[F] during his organization
phase.  Cannot be duplicated at
a given site.|
Return of the King,Resource,R,Permanent-event,3,0,3,0,0,0,0,0,0,0,0,Rob Alexander,3,|Unique.  Aragorn II only.  Only
playable in Minas Tirith and
only if Denethor II is not in
play.  Aragorn II''s direct
influence is modified by +3.
Keep this card with Aragorn II;
discard if he leaves play.|
Riders of Rohan,Resource,F1,Man faction,3,0,0,0,0,0,0,0,0,0,0,Donato Giancola,4,|Unique.  Playable at Edoras if
the influence check is greater
than 9.  Standard Modifications:
Hobbits (+1), Dunedain (+1).|
Ringlore,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,5,|Sage only, only playable at a
site where "Information" is
playable, and only if a
character in his company has a
Gold Ring.  Play to test a Gold
Ring.  No roll (or draw) is
used.  The player may replace
the Gold Ring with any ring from
his hand (except for The One
Ring).|
Risky Blow,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,5,|Warrior only against one strike.
+3 to prowess and -1 to body.|
Roac the Raven,Resource,R,Diplomat ally,1,1,0,8,-3,0,0,0,0,0,0,Mark Poole,9,|Unique.  Playable at any site in
Northern Rhovanion.  Tap and
discard to attempt to bring any
faction into play - no
modifications to the influence
check are required.|
Sacrifice of Form,Resource,R,Permanent-event,0,0,0,0,0,0,0,0,0,0,0,Rob Alexander,3,|Spell.  Wizard only.  All of the
strikes from one attack against
your Wizard''s company fail; -3
to any body checks made to
determine if the attack is
defeated.  Discard the Wizard
(i.e. he becomes unrevealed) and
any non-item cards he controls.
Place any items he controls
under his card and keep these
off to the side (these items are
considered to still be in play).
If the Wizard is put back into
play, return his items to him
and place Sacrifice of Form with
him.  Wizard receives +1 to his
prowess, body and direct
influence.  May not be
duplicated on a given Wizard.|
Sapling of the White Tree,Resource,U,Major item,1,0,0,0,0,1,2,0,0,0,0,Lori Deitrick,5,|Not playable in a Shadow-hold
[S] or Dark-hold [D].  May be
stored at Minas Tirith.  2
marshalling points if stored at
Minas Tirith.|
Scroll of Isildur,Resource,U,Greater item,4,0,0,0,0,3,0,0,0,0,0,Ron Rousselle II,5,|Unique.  When a Gold Ring is
tested in a company with the
Scroll of Isildur, the result of
the roll (or draw) is modified
by +2.|
Secret Entrance,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Randy Asplund-Faith,7,|Only playable at the end of the
organization phase; may not be
played on a company that is
moving to a site in a
Dark-domain [d].  Tap a sage in
the company, and no hazard
creatures keyed to the site may
be played on the company.|
Secret Passage,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Kevin Ward,6,|Playable only at the end of the
organization phase.  If the
company that it is played on
moves to a Ruins & Lairs [R]
site, opponent may only play
hazard creatures that are keyed
to the company''s site.|
Shadowfax,Resource,R,Ally,1,2,0,2,8,0,0,0,0,0,0,Angus McBride,9,|Unique.  Playable at Edoras or
Dunharrow.  If his company has
only one character or one
character and a Hobbit at the
end of the movement/hazard
phase, tap Shadowfax to allow
his company to immediately move
again; an additional site card
may be played and an additional
movement/hazard phase follows
for that company.|
Shield of Iron-bound Ash,Resource,CA2,Minor item,0,0,0,0,1,1,0,0,1,0,0,Ronald Shuey,5,|Shield.  +1 to body to a maximum
of 8.  Tap Shield of Iron-bound
Ash to gain +1 prowess against
one strike.|
Skinbark,Resource,R,Ally,2,3,0,10,9,0,0,0,0,0,0,Gail McIntosh,9,|Unique.  Playable at
Wellinghall.  May not be
attacked by automatic-attacks or
hazards keyed to his site.
discard Skinbark if his company
moves to a site that is not in:
Fangorn, Rohan, Gap of Isen,
Wold & Foothills, Anduin Vales,
or Redhorn Gap.|
Southrons,Resource,R,Man faction,5,0,0,0,0,0,0,0,0,0,0,Brian Snoddy,3,|Unique.  Playable at the
Southron Oasis if the influence
check is greater than 8.
Standard Modifications: Dunedain
(-2), Elves (-2), Dwarves (-2).|
Star-glass,Resource,U,Minor item,0,0,0,0,0,1,0,0,0,0,0,Randy Asplund-Faith,8,|Tap bearer of Star-glass to
cancel an attack by Undead or to
modify the prowess of a spiders,
animals, or wolves attack by -2.
Bearer makes a corruption check.|
Stars,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Douglas Chaffee,8,|Environment.  Modify the prowess
of one Undead attack by -1.
Alternatively, if Gates of
Morning is in play, until the
end of the turn, treat one
Dark-domain [d] as a Shadow-land
[s] or one Shadow-land [s] as a
Wilderness [w].  Cannot be
duplicated.|
Stealth,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Quinton Hoover,5,|Scout only.  Tap a scout to play
at the end of the organization
phase only if the scout''s
company size is less than three.
No creature hazards may be
played on his company this turn.|
Sting,Resource,U,Minor item,0,0,0,1,0,1,0,0,2,0,0,Randy Asplund-Faith,5,|Unique.  Weapon.  +1 prowess to
a maximum of 8, +2 to a Hobbit''s
prowess to a maximum of 8.|
Stone of Erech,Resource,R,Permanent-event,2,0,0,0,0,0,0,0,0,0,0,J. Wallace Jones,5,|Unique.  Playable at the Vale of
Erech and if the Men of Lamedon
are already in play.  Discard if
the Men of Lamedon leave play.|
Sun,Resource,U,Long-event,0,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,8,|Environment.  The prowess of
each Dunadan is modified by +1.
Additionally, if Gates of
Morning is in play, the prowess
of each automatic-attack and
hazard creature is modified by
-1 and the prowess of each Man
and Dunadan is modified by +1.
Cannot be duplicated.|
Sword of Gondolin,Resource,CA2,Major item,2,0,0,2,0,2,0,0,0,0,0,Mark Poole,4,|Weapon.  Warrior only: +2 to
prowess to a maximum of 8.|
Tempering Friendship,Resource,CB2,Short-event,0,0,0,0,0,0,0,0,0,0,0,David Deitrick,4,|+4 to an influence attempt
against a faction.|
Test of Form,Resource,CA2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,4,|Sage only, and only if a
character in his company has a
Gold Ring.  Play to test a Gold
Ring.|
Test of Lore,Resource,CA2,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,4,|Sage only, and only if a
character in his company has a
Gold Ring.  Play to test a Gold
Ring; subtract one from the
result of the roll (or draw).|
The Arkenstone,Resource,R,Greater item,2,0,0,0,0,2,5,3,0,0,4,Randy Asplund-Faith,7,|Unique.  +3 to bearer''s direct
influence against Dwarves and
Dwarf factions.  If held by a
Dwarf, The Arkenstone gives 5
marshalling points and 4
corruption points.  The
Arkenstone may be tapped to
untap a Dwarf character in the
same company, but target Dwarf
must make a corruption check
modified by -2.|
The Cock Crows,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,April Lee,4,|Cancels a Troll attack.
Alternatively, if Gates of
Morning is in play, it forces
the discard of one hazard
permanent-event.|
The Evenstar,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,10,|Environment.  The prowess of one
Elf is modified by +1 until the
end of the turn.  Additionally,
if Gates of Morning is in play,
until the end of the turn, the
prowess of each Elf is modified
by +1 and treat one Wilderness
[w] as a Border-land [b], or one
Border-land [b] as a Free-domain
[f].  Cannot be duplicated.|
The Great Eagles,Resource,U,Eagle faction,3,0,0,0,0,0,0,0,0,0,0,Jo Hartwig,7,|Unique.  Playable at Eagles''
Eyrie if the influence check is
greater than 9.  Standard
Modifications: none.|
The Mithril-coat,Resource,R,Greater item,4,0,0,0,3,2,0,0,0,0,0,Mark Poole,10,|Unique.  Armor.  +3 body (to a
maximum of 10).|
The Old Thrush,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Mark Poole,6,|-3 to the prowess and body of a
non-Nazgul attack with a prowess
of 13 or more.|
The One Ring,Resource,R,Special item,6,0,5,5,5,6,0,0,0,0,0,Angelo Montanini,9,|Unique.  The One Ring.  Playable
only with a Gold Ring and after
a test indicates The One Ring.
+5 prowess (to a maximum of
double the bearer''s starting
prowess).  +5 body (to a maximum
of 10).  +5 to direct influence.
Bearer may make a corruption
check modified by -2 to cancel a
strike; this does not work
against Undead and Nazgul
strikes.  +1 corruption point to
every character in the bearer''s
company.|
The White Tree,Resource,R,Permanent-event,5,0,0,0,0,0,0,0,0,0,0,Kevin Ward,11,|Unique.  Sage only at Minas
Tirith.  Playable only if a
Sapling of the White Tree is at
Minas Tirith.  Minas Tirith
becomes a Haven [H] for the
purposes of healing and playing
hazards.|
Thorough Search,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Donato Giancola,3,|Scout only.  Tap a scout during
the site phase to allow another
character in his company to play
any item normally found at its
current site.  The company must
face any automatic-attack for
its current site at least once
diring this site phase.  This
does not tap the site, and
Thorough Search can be played at
a site that is already tapped.|
Tom Bombadil,Resource,R,Sage ally,3,4,0,12,11,0,0,0,0,0,0,Angus McBride,9,|Unique.  Playable at Old Forest.
Tap to cancel the effects of one
hazard that targets any company
moving to a site in: Arthedain,
Cardolan, Rhudaur, of The SHire.
Discard Tom Bombadil if his
company moves to a site that is
not in: Arthedain, Cardolan,
Rhudaur, or The Shire.|
Torque of Hues,Resource,U,Major item,2,0,0,0,0,2,0,0,0,0,0,Quinton Hoover,4,|Unique.  Tap Torque of Hues and
its bearer to cancel an attack
against his company.  Bearer
makes a corruption check.|
Tower Guard of Minas Tirith,Resource,F1,Dunadan faction,2,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,3,|Unique.  Playable at Minas
Tirith if the influence check is
greater than 7.  Standard
Modifications:  Dunedain (+1).|
Treebeard,Resource,U,Sage ally,2,3,0,8,9,0,0,0,0,0,0,Angus McBride,8,|Unique.  Playable at
Wellinghall.  May not be
attacked by automatic-attacks or
hazards keyed to his site.
Discard Treebeard if his company
moves to a site that is not in:
Fangorn, Rohan, Gap of Isen,
Wold & Foothills, Enedhwaith,
Old Pukel-land, Brown Lands,
Anduin Vales, or Redhorn Gap.|
True Fana,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,David Cherry,9,|Spell.  Wizard only.  Before
resolving an attack against the
Wizard''s company, make a roll
(or draw a #) and add the
Wizard''s prowess to the result.
If the total is greater than the
attack''s prowess, all of the
attack''s strikes fail (if the
attack has a body, make body
checks to determine if the
attack is defeated).  Otherwise,
the attack proceeds normally.
Wizard makes a corruption check
modified by -3.|
Use Palantir,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,3,|Sage only.  Tap sage to use a
Palantir that he controls.|
Vanishment,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,2,|Spell.  Wizard only.  Cancels an
attack against the Wizard''s
company.  Wizard makes a
corruption check modified by -2.|
Variags of Khand,Resource,R,Man faction,4,0,0,0,0,0,0,0,0,0,0,Heather Hudson,2,|Unique.  Playable at Variag Camp
if the influence check is
greater than 9.  Standard
Modifications: none.|
Vilya,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Darryl Elliott,12,|Elrond only.  +4 prowess, +2
body, +6 direct influence until
the end of the turn.  If your
play deck has at least 5 cards
in it, you may take 5 resource
cards of your choice from your
discard pile and shuffle them
into your play deck.  Elrond
makes a corruption check
modified by -3.|
White Mountains,Resource,CB,Short-event,0,0,0,0,0,0,0,0,0,0,0,David Martin,5,|Playable at the end of the
organization phase on a company
containing a ranger.  If the
company uses region cards for
its site path, tap the ranger to
move as if the following pairs
of regions were adjacent: Old
Pukel-land and Anfalas, Rohan
and Lamedon, Rohan and Anfalas,
Anorien and Lamedon.  Otherwise,
if the site moved to is in one
of the regions listed above, the
hazard limit is reduced by two
(to a minimum of two).  Cannot
be duplicated on a given
company.|
Wizard''s Fire,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Edward Beard, Jr.,11,|Spell.  Wizard only.  +5 prowess
for the Wizard against one
attack.  Wizard makes a
corruption check modified by -4.|
Wizard''s Flame,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Lori Deitrick,10,|Spell.  Wizard only.  All
attacks against Wizard''s company
suffer a -2 modification to
prowess for the rest of the
turn.  Wizard makes a corruption
check modified by -3.|
Wizard''s Laughter,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Edward Beard, Jr.,10,|Spell.  Wizard only.
Automatically cancels an
influence check against one of
the Wizard''s player''s
characters, followers, factions,
allies, or items.  Wizard makes
a corruption check modified by
-2.|
Wizard''s Ring,Resource,R,Special item,2,0,5,2,1,4,0,0,0,0,0,Ron Rousselle II,4,|Wizard only.  Playable only at a
Haven [H].  Ignore any effect
that would discard this item.
May not be duplicated on a given
Wizard.  Bearer makes a
corruption check when this item
is played.|
Wizard''s River-horses,Resource,U,Short-event,0,0,0,0,0,0,0,0,0,0,0,Rob Alexander,10,|Spell.  Wizard only.  All Nazgul
events are discarded or cancels
an attack against a Wizard if he
is the only character in the
company.  Wizard makes a
corruption check modified by -2.|
Wizard''s Test,Resource,CA,Short-event,0,0,0,0,0,0,0,0,0,0,0,Angus McBride,9,|Spell.  Wizard only, and only if
a character in his company has a
Gold Ring.  Play to test a Gold
Ring; make two rolls (or draw
two #''s) and choose one result
to use for the test.  Wizard
makes a corruption check
modified by -1.|
Wizard''s Voice,Resource,R,Short-event,0,0,0,0,0,0,0,0,0,0,0,Ron Spencer,9,|Spell.  Wizard only.  +6 to
direct influence for the Wizard
for the rest of the turn.
Wizard makes a corruption check
modified by -3.  May not be
duplicated on a given Wizard.|
Wood-elves,Resource,F1,Elf faction,3,0,0,0,0,0,0,0,0,0,0,Liz Danforth,12,|Unique.  Playable at Thranduil''s
Halls if the influence check is
greater than 8.  Standard
Modifications: Men (-1), Elves
(+1), Dwarves (-2).|
Woodmen,Resource,U,Man faction,2,0,0,0,0,0,0,0,0,0,0,Angelo Montanini,11,|Unique.  Playable at
Woodmen-town if the influence
check is greater than 7.
Standard Modifications: Men
(+1).|
Woses of Old Pukel-land,Resource,R,Wose faction,3,0,0,0,0,0,0,0,0,0,0,Stefano Baldo,11,|Unique.  Playable at Wose
Passage-hold if the influence
check is greater than 8.
Standard Modifications: none.|
Woses of the Druadan Forest,Resource,U,Wose faction,3,0,0,0,0,0,0,0,0,0,0,Edward Beard, Jr.,10,|Unique.  Playable at Druadan
Forest if the influence check is
greater than 9.  Standard
Modifications: none.|'.! !

MEGElementFactory subclass: #MEGSiteFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGSiteFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:47'!
newSiteNamed: aString

	^self newSites detect: [ :each | each name = aString ].! !

!MEGSiteFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 20:32'!
newSites
	^ self sitesFromString: self spoilerString! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 20:38'!
siteFromLine: aString
	| fields site |
	fields := aString substrings: #($,).
	site := MEGSite new.
	site name: fields first.
	site type: (self siteTypeFor: fields fifth).
	^site.! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 20:40'!
siteTypeFor: code

	| result |
	(code = 'H') ifTrue: [ result := 'Haven' ].
	^result.! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 21:20'!
sitesFromString: aString

	^aString lines collect: [ :line | self siteFromLine: line ].! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 21:22'!
spoilerString

	^'Amon Hen,Site,CA,Rohan,R,wb,Lorien,,,1,1,info/min,Undead,1,6,,0,0,|Each character wounded must make a corruption check.|,David Martin
Bag End,Site,F2,Shire,F,wwf,Rivendell,,,2,2,,,0,0,,0,0,||,Randy Asplund-Faith
Bandit Lair,Site,F3,Brown Lands,R,ws,Lorien,,,1,2,min/ring,Men,3,6,,0,0,||,Darryl Elliott
Barad-dur,Site,R,Gorgoroth,D,wbfwsd,Lorien,,,3,6,min/maj/gr,Orcs,4,7,Trolls,3,9,|Any company moving to Barad-Dur has its hazard limit modified by +2.|,Kevin Ward
Barrow-downs,Site,F1,Cardolan,R,ww,Rivendell,,,1,2,min/maj,Undead,1,8,,0,0,|Each character wounded must make a corruption check.|,Angus McBride
Beorn''s House,Site,F1,Anduin Vales,F,wb,Lorien,,,1,1,,,0,0,,0,0,||,Eric David Anderson
Blue Mountain Dwarf-hold,Site,CB,Numeriador,F,fw,Grey Havens,,,1,1,,,0,0,,0,0,||,Rob Alexander
Bree,Site,F1,Arthedain,B,ww,Rivendell,,,1,1,,,0,0,,0,0,||,Randy Gallegos
Cameth Brin,Site,CB,Rhudaur,B,w,Rivendell,,,1,1,,,0,0,,0,0,||,David Martin
Carn Dum,Site,R,Angmar,D,ws,Rivendell,,,2,3,min/maj/gr,Orcs,4,7,,0,0,||,J. Wallace Jones
Caves of Ulund,Site,U,Withered Heath,R,wbsw,Lorien,,,3,3,min/maj/gr/ring,Dragon,1,13,,0,0,||,Randy Asplund-Faith
Cirith Ungol,Site,R,Imlad Morgul,D,wbfws,Lorien,,,3,4,min/maj/gr,Orcs,4,7,,0,0,||,Mark Poole
Dancing Spire,Site,U,Withered Heath,R,wbsw,Lorien,,,3,3,min/maj/gr/ring,Dragon,2,11,,0,0,||,Pat Morrissey
Dead Marshes,Site,U,Dagorlad,S,wss,Lorien,,,2,3,min/maj/gr,Undead,2,8,,0,0,|Each character wounded must make a corruption check.|,Pat Morrissey
Dimrill Dale,Site,U,Redhorn Gate,R,ww,Lorien,,,1,1,info,Orcs,1,6,,0,0,||,Eric David Anderson
Dol Amroth,Site,CB,Belfalas,F,wf,Edhellond,,,1,1,,,0,0,,0,0,||,Mark Poole
Dol Guldur,Site,R,Southern Mirkwood,D,wbd,Lorien,,,2,4,min/maj/gr,Orcs,3,7,Trolls,2,8,||,Christina Wald
Druadan Forest,Site,CB,Anorien,B,wbf,Lorien,,,2,2,,,0,0,,0,0,||,Edward Beard, Jr.
Dunharrow,Site,R,Rohan,B,wb,Lorien,,,1,1,,,0,0,,0,0,||,N. Taylor Blanchard
Dunnish Clan-hold,Site,F1,Dunland,B,www,Rivendell,,,2,2,,,0,0,,0,0,||,Storn Cook
Eagles'' Eyrie,Site,CB,Anduin Vales,F,wb,Lorien,,,1,1,,,0,0,,0,0,||,Rob Alexander
Easterling Camp,Site,R,Horse Plains,B,wsss,Lorien,,,4,4,,,0,0,,0,0,||,Storn Cook
Edhellond,Site,CB,Anfalas,H,fccccw,Grey Havens,wbffbw,Lorien,2,2,,,0,0,,0,0,||,Christina Wald
Edoras,Site,F1,Rohan,F,wb,Lorien,,,1,1,,,0,0,,0,0,||,Margaret Organ-Keane
Ettenmoors,Site,CA,Rhudaur,R,w,Rivendell,,,1,1,min,Troll,1,9,,0,0,||,Rob Alexander
Gladden Fields,Site,CA,Anduin Vales,R,wb,Lorien,,,1,1,ring,Undead,1,8,,0,0,|Each character wounded must make a corruption check.|,Quinton Hoover
Glittering Caves,Site,U,Gap of Isen,R,wbb,Lorien,,,2,2,min/maj,Pukel-man,1,9,,0,0,||,David Martin
Goblin-gate,Site,F2,High Pass,S,ww,Rivendell,,,1,2,min/ring,Orcs,3,6,,0,0,||,Randy Gallegos
Grey Havens,Site,CB,Lindon,H,wwf,Rivendell,wccccf,Edhellond,2,2,,,0,0,,0,0,||,Mark Poole
Henneth Annun,Site,F1,Ithilien,B,wbfw,,,,2,2,,,0,0,,0,0,||,Rob Alexander
Himring,Site,U,Elven Shores,R,fc,Grey Havens,,,1,1,min/maj,Undead,1,8,,0,0,|Each character wounded must make a corruption check.|,J. Wallace Jones
Irerock,Site,U,Withered Heath,R,wbsw,Lorien,,,3,3,min/maj/gr/ring,Dragon,1,14,,0,0,||,Pat Morrissey
Iron Hill Dwarf-hold,Site,F1,Iron Hills,F,wbbww,Lorien,,,3,3,,,0,0,,0,0,||,Ron Rousselle II
Isengard,Site,F2,Gap of Isen,R,wbb,Lorien,,,2,2,min/maj/ring,Wolves,3,7,,0,0,||,Eric David Anderson
Isles of the Dead that Live,Site,R,Eriadoran Coast,R,fcc,Grey Havens,,,1,2,min/maj/ring,Undead,2,8,,0,0,|Each character wounded must make a corruption check.|,Rob Alexander
Lake-town,Site,CB,Northern Rhovanion,B,wbbw,Lorien,,,2,2,,,0,0,,0,0,||,Eric David Anderson
Lond Galen,Site,CB,Anfalas,B,w,Edhellond,,,1,1,,,0,0,,0,0,||,J. Wallace Jones
Lorien,Site,CB,Wold & Foothills,H,wwbw,Rivendell,wbffbw,Edhellond,2,2,,,0,0,,0,0,||,Stefano Baldo
Lossadan Cairn,Site,CA,Forochel,R,www,Rivendell,,,2,2,min/maj/gr,Undead,2,8,,0,0,|*--Palantiri Only Each character wounded must make a corruption check.|,J. Wallace Jones
Lossadan Camp,Site,CB,Forochel,B,www,Rivendell,,,2,2,,,0,0,,0,0,||,Lori Deitrick
Minas Morgul,Site,R,Imlad Morgul,D,wbfws,Lorien,,,3,4,min/maj/gr,Undead,3,8,,0,0,|Each character wounded must make a corruption check.|,Angus McBride
Minas Tirith,Site,F2,Anorien,F,wbf,Lorien,,,2,2,,,0,0,,0,0,||,Eric David Anderson
Moria,Site,F3,Redhorn Gate,S,ww,Lorien,,,2,3,min/maj/gr/ring,Orcs,4,7,,0,0,||,Kevin Ward
Mount Doom,Site,U,Gorgoroth,S,wbfwsd,Lorien,,,3,6,,,0,0,,0,0,|Any company moving to Mount Doom has its hazard limit modified by +2 and hazard creatures may always be played keyed to the site regardless of any other cards played.|,J. Wallace Jones
Mount Gram,Site,F2,Angmar,S,ws,Rivendell,,,2,3,min/maj,Orcs,3,6,,0,0,||,Susan Van Camp
Mount Gundabad,Site,U,Gundabad,S,wbd,Lorien,,,2,3,min/maj/gr,Orcs,2,8,,0,0,||,Angus McBride
Old Forest,Site,CA,Cardolan,B,ww,Rivendell,,,1,1,,,0,0,,0,0,|Healing Cards affect all characters at the site.|,Kevin Ward
Ost-in-Edhil,Site,U,Hollin,R,ww,Rivendell,,,1,1,min/ring,Wolves,3,5,,0,0,||,Mark Poole
Pelargir,Site,CB,Lebennin,F,wbf,Edhellond,,,2,2,,,0,0,,0,0,||,J. Wallace Jones
Rhosgobel,Site,F2,Southern Mirkwood,F,wbd,Lorien,,,2,3,min,,0,0,,0,0,|Healing Cards affect all characters at the site.|,Tom Dow
Rivendell,Site,CB,Rhudaur,H,wbww,Lorien,fww,Grey Havens,2,2,,,0,0,,0,0,||,Stefano Baldo
Ruined Signal Tower,Site,F2,Enedhwaith,R,www,Rivendell,,,2,2,min/maj,Spiders,2,8,,0,0,||,Mark Poole
Sarn Goriwing,Site,CA,Heart of Mirkwood,S,wbww,Lorien,,,2,2,min/maj,Orcs,3,5,,0,0,||,J. Wallace Jones
Shelob''s Lair,Site,R,Imlad Morgul,S,wbfws,Lorien,,,3,4,min/maj,Orcs,2,8,,0,0,||,Kevin Ward
Shrel-Kain,Site,CB,Dorwinion,B,wbbwb,Lorien,,,3,3,,,0,0,,0,0,||,J. Wallace Jones
Southron Oasis,Site,R,Harondor,B,wfcw,Edhellond,,,2,2,,,0,0,,0,0,||,Tom Dow
Stone-circle,Site,R,Old Pukel Gap,R,ww,Edhellond,,,1,1,info/min,Pukel-man,1,9,,0,0,||,Christina Wald
The Lonely Mountain,Site,F2,Northern Rhovanion,R,wbbw,Lorien,,,2,2,min/maj/gr/ring,Dragon,1,14,,0,0,||,Rob Alexander
The Stones,Site,R,Andrast,R,ww,Edhellond,,,1,1,min/maj/gr,Pukel-men,2,9,,0,0,||,Pat Morrissey
The White Towers,Site,U,Arthedain,R,ww,Rivendell,,,1,1,,Wolves,2,6,,0,0,||,Audrey Corman
The Wind Throne,Site,F5,Grey Mountain Narrows,R,wbs,Lorien,,,2,2,info/min/maj,Orcs,3,7,,0,0,||,Pat Morrissey
Thranduil''s Halls,Site,F1,Woodland Realms,F,wbb,Lorien,,,2,2,,,0,0,,0,0,||,Mark Forrer
Tolfalas,Site,R,Mouths of the Anduin,R,wfc,Edhellond,,,2,2,min/maj/gr,Undead,3,7,,0,0,|Each character wounded must make a corruption check.|,Douglas Chaffee
Vale of Erech,Site,R,Lamedon,B,wb,Edhellond,,,1,1,,,0,0,,0,0,||,J. Wallace Jones
Variag Camp,Site,R,Khand,B,wfcws,Edhellond,,,3,4,,,0,0,,0,0,||,Storn Cook
Weathertop,Site,F4,Arthedain,R,ww,Rivendell,,,1,1,info,Wolves,2,6,,0,0,||,Tom Dow
Wellinghall,Site,F1,Fangorn,F,ww,Lorien,,,1,1,,,0,0,,0,0,||,Angus McBride
Woodmen-town,Site,CB,Western Mirkwood,B,wbw,Lorien,,,2,2,,,0,0,,0,0,||,J. Wallace Jones
Wose Passage-hold,Site,CB,Old Pukel-land,B,www,Edhellond,,,2,2,,,0,0,,0,0,||,J. Wallace Jones'.! !

Object subclass: #MEGWorldFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGWorldFactory methodsFor: 'public' stamp: 'FedericoFigueredo 6/22/2016 08:42'!
newWorld
	| world gandalf characters wizard |
	world := MEGWorld new.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	gandalf baseInfluence: 10.
	gandalf marshallingPoints: 0.
	characters := MEGCharacterFactory new newCharacters.
	wizard := MEGAgent named: 'Jugador 1'.
	world addSites: MEGSiteFactory new newSites.
	world addCharacter: gandalf.
	world addCharacters: characters.
	world addAgent: wizard.
	world addAgent: (MEGAgent named: 'Jugador 2').
	world addFactions: MEGResourcesFactory new newFactions.
	^ world! !

!MEGWorldFactory methodsFor: 'public' stamp: 'SergioFedi 6/15/2016 23:10'!
newWorldWithCharacterPlayed: aString at: aString2 for: aString3

	^self newWorldWithCharacterPlayed: aString at: aString2 for: aString3 inCompany: 'New Company'.! !

!MEGWorldFactory methodsFor: 'public' stamp: 'SergioFedi 6/24/2016 16:32'!
newWorldWithCharacterPlayed: aString at: aString2 for: aString3 inCompany: aString4 
	| world result |
	world := self newWorld.
	result := (world agentNamed: aString3) recruit: aString at: aString2 inCompany: aString4.
	result hasErrors ifTrue: [ self error: 'Creation of world failed: ', (result errors first truncateWithElipsisTo: 25) ].
	^ world.! !
